@@ -65,7 +65,7 @@ struct tevent_req *dcerpc_QueryInterface_send(TALLOC_CTX *mem_ctx,
 					      struct ORPCTHAT *_ORPCthat /* [out] [ref] */,
 					      struct ORPCTHIS _ORPCthis /* [in]  */,
 					      struct GUID *_iid /* [in] [unique] */,
-					      struct MInterfacePointer **_data /* [out] [ref,iid_is(riid)] */);
+					      struct MInterfacePointer **_data /* [out] [iid_is(riid),ref] */);
 NTSTATUS dcerpc_QueryInterface_recv(struct tevent_req *req,
 				    TALLOC_CTX *mem_ctx,
 				    WERROR *result);
@@ -74,7 +74,7 @@ NTSTATUS dcerpc_QueryInterface(struct dcerpc_binding_handle *h,
 			       struct ORPCTHAT *_ORPCthat /* [out] [ref] */,
 			       struct ORPCTHIS _ORPCthis /* [in]  */,
 			       struct GUID *_iid /* [in] [unique] */,
-			       struct MInterfacePointer **_data /* [out] [ref,iid_is(riid)] */,
+			       struct MInterfacePointer **_data /* [out] [iid_is(riid),ref] */,
 			       WERROR *result);
 
 struct tevent_req *dcerpc_AddRef_r_send(TALLOC_CTX *mem_ctx,
@@ -456,7 +456,7 @@ struct tevent_req *dcerpc_RemQueryInterface2_send(TALLOC_CTX *mem_ctx,
 						  struct ORPCTHIS _ORPCthis /* [in]  */,
 						  struct GUID *_ripid /* [in] [unique] */,
 						  uint16_t _cIids /* [in]  */,
-						  struct GUID *_iids /* [in] [size_is(cIids),unique] */,
+						  struct GUID *_iids /* [in] [unique,size_is(cIids)] */,
 						  WERROR *_phr /* [out] [size_is(cIids),unique] */,
 						  struct MInterfacePointer *_ppMIF /* [out] [unique,size_is(cIids)] */);
 NTSTATUS dcerpc_RemQueryInterface2_recv(struct tevent_req *req,
@@ -468,7 +468,7 @@ NTSTATUS dcerpc_RemQueryInterface2(struct dcerpc_binding_handle *h,
 				   struct ORPCTHIS _ORPCthis /* [in]  */,
 				   struct GUID *_ripid /* [in] [unique] */,
 				   uint16_t _cIids /* [in]  */,
-				   struct GUID *_iids /* [in] [size_is(cIids),unique] */,
+				   struct GUID *_iids /* [in] [unique,size_is(cIids)] */,
 				   WERROR *_phr /* [out] [size_is(cIids),unique] */,
 				   struct MInterfacePointer *_ppMIF /* [out] [unique,size_is(cIids)] */,
 				   WERROR *result);
@@ -710,7 +710,7 @@ struct tevent_req *dcerpc_Write_send(TALLOC_CTX *mem_ctx,
 				     struct dcerpc_binding_handle *h,
 				     struct ORPCTHAT *_ORPCthat /* [out] [ref] */,
 				     struct ORPCTHIS _ORPCthis /* [in]  */,
-				     uint8_t *_data /* [in] [unique,size_is(num_requested)] */,
+				     uint8_t *_data /* [in] [size_is(num_requested),unique] */,
 				     uint32_t _num_requested /* [in]  */,
 				     uint32_t *_num_written /* [out] [ref] */);
 NTSTATUS dcerpc_Write_recv(struct tevent_req *req,
@@ -720,7 +720,7 @@ NTSTATUS dcerpc_Write(struct dcerpc_binding_handle *h,
 		      TALLOC_CTX *mem_ctx,
 		      struct ORPCTHAT *_ORPCthat /* [out] [ref] */,
 		      struct ORPCTHIS _ORPCthis /* [in]  */,
-		      uint8_t *_data /* [in] [unique,size_is(num_requested)] */,
+		      uint8_t *_data /* [in] [size_is(num_requested),unique] */,
 		      uint32_t _num_requested /* [in]  */,
 		      uint32_t *_num_written /* [out] [ref] */,
 		      WERROR *result);
