@@ -31,7 +31,7 @@ struct tevent_req *dcerpc_dfs_Add_send(TALLOC_CTX *mem_ctx,
 				       struct tevent_context *ev,
 				       struct dcerpc_binding_handle *h,
 				       const char *_path /* [in] [charset(UTF16),ref] */,
-				       const char *_server /* [in] [charset(UTF16),ref] */,
+				       const char *_server /* [in] [ref,charset(UTF16)] */,
 				       const char *_share /* [in] [charset(UTF16),unique] */,
 				       const char *_comment /* [in] [charset(UTF16),unique] */,
 				       uint32_t _flags /* [in]  */);
@@ -41,7 +41,7 @@ NTSTATUS dcerpc_dfs_Add_recv(struct tevent_req *req,
 NTSTATUS dcerpc_dfs_Add(struct dcerpc_binding_handle *h,
 			TALLOC_CTX *mem_ctx,
 			const char *_path /* [in] [charset(UTF16),ref] */,
-			const char *_server /* [in] [charset(UTF16),ref] */,
+			const char *_server /* [in] [ref,charset(UTF16)] */,
 			const char *_share /* [in] [charset(UTF16),unique] */,
 			const char *_comment /* [in] [charset(UTF16),unique] */,
 			uint32_t _flags /* [in]  */,
@@ -56,7 +56,7 @@ NTSTATUS dcerpc_dfs_Remove_r(struct dcerpc_binding_handle *h, TALLOC_CTX *mem_ct
 struct tevent_req *dcerpc_dfs_Remove_send(TALLOC_CTX *mem_ctx,
 					  struct tevent_context *ev,
 					  struct dcerpc_binding_handle *h,
-					  const char *_dfs_entry_path /* [in] [ref,charset(UTF16)] */,
+					  const char *_dfs_entry_path /* [in] [charset(UTF16),ref] */,
 					  const char *_servername /* [in] [unique,charset(UTF16)] */,
 					  const char *_sharename /* [in] [charset(UTF16),unique] */);
 NTSTATUS dcerpc_dfs_Remove_recv(struct tevent_req *req,
@@ -64,7 +64,7 @@ NTSTATUS dcerpc_dfs_Remove_recv(struct tevent_req *req,
 				WERROR *result);
 NTSTATUS dcerpc_dfs_Remove(struct dcerpc_binding_handle *h,
 			   TALLOC_CTX *mem_ctx,
-			   const char *_dfs_entry_path /* [in] [ref,charset(UTF16)] */,
+			   const char *_dfs_entry_path /* [in] [charset(UTF16),ref] */,
 			   const char *_servername /* [in] [unique,charset(UTF16)] */,
 			   const char *_sharename /* [in] [charset(UTF16),unique] */,
 			   WERROR *result);
@@ -79,8 +79,8 @@ struct tevent_req *dcerpc_dfs_SetInfo_send(TALLOC_CTX *mem_ctx,
 					   struct tevent_context *ev,
 					   struct dcerpc_binding_handle *h,
 					   const char *_dfs_entry_path /* [in] [charset(UTF16)] */,
-					   const char *_servername /* [in] [unique,charset(UTF16)] */,
-					   const char *_sharename /* [in] [unique,charset(UTF16)] */,
+					   const char *_servername /* [in] [charset(UTF16),unique] */,
+					   const char *_sharename /* [in] [charset(UTF16),unique] */,
 					   uint32_t _level /* [in]  */,
 					   union dfs_Info *_info /* [in] [ref,switch_is(level)] */);
 NTSTATUS dcerpc_dfs_SetInfo_recv(struct tevent_req *req,
@@ -89,8 +89,8 @@ NTSTATUS dcerpc_dfs_SetInfo_recv(struct tevent_req *req,
 NTSTATUS dcerpc_dfs_SetInfo(struct dcerpc_binding_handle *h,
 			    TALLOC_CTX *mem_ctx,
 			    const char *_dfs_entry_path /* [in] [charset(UTF16)] */,
-			    const char *_servername /* [in] [unique,charset(UTF16)] */,
-			    const char *_sharename /* [in] [unique,charset(UTF16)] */,
+			    const char *_servername /* [in] [charset(UTF16),unique] */,
+			    const char *_sharename /* [in] [charset(UTF16),unique] */,
 			    uint32_t _level /* [in]  */,
 			    union dfs_Info *_info /* [in] [ref,switch_is(level)] */,
 			    WERROR *result);
@@ -108,7 +108,7 @@ struct tevent_req *dcerpc_dfs_GetInfo_send(TALLOC_CTX *mem_ctx,
 					   const char *_servername /* [in] [charset(UTF16),unique] */,
 					   const char *_sharename /* [in] [unique,charset(UTF16)] */,
 					   uint32_t _level /* [in]  */,
-					   union dfs_Info *_info /* [out] [switch_is(level),ref] */);
+					   union dfs_Info *_info /* [out] [ref,switch_is(level)] */);
 NTSTATUS dcerpc_dfs_GetInfo_recv(struct tevent_req *req,
 				 TALLOC_CTX *mem_ctx,
 				 WERROR *result);
@@ -118,7 +118,7 @@ NTSTATUS dcerpc_dfs_GetInfo(struct dcerpc_binding_handle *h,
 			    const char *_servername /* [in] [charset(UTF16),unique] */,
 			    const char *_sharename /* [in] [unique,charset(UTF16)] */,
 			    uint32_t _level /* [in]  */,
-			    union dfs_Info *_info /* [out] [switch_is(level),ref] */,
+			    union dfs_Info *_info /* [out] [ref,switch_is(level)] */,
 			    WERROR *result);
 
 struct tevent_req *dcerpc_dfs_Enum_r_send(TALLOC_CTX *mem_ctx,
