@@ -14,10 +14,10 @@ NTSTATUS dcerpc_DnssrvOperation_r(struct dcerpc_binding_handle *h, TALLOC_CTX *m
 struct tevent_req *dcerpc_DnssrvOperation_send(TALLOC_CTX *mem_ctx,
 					       struct tevent_context *ev,
 					       struct dcerpc_binding_handle *h,
-					       const char *_pwszServerName /* [in] [charset(UTF16),unique] */,
-					       const char *_pszZone /* [in] [unique,charset(UTF8)] */,
+					       const char *_pwszServerName /* [in] [unique,charset(UTF16)] */,
+					       const char *_pszZone /* [in] [charset(UTF8),unique] */,
 					       uint32_t _dwContext /* [in]  */,
-					       const char *_pszOperation /* [in] [charset(UTF8),unique] */,
+					       const char *_pszOperation /* [in] [unique,charset(UTF8)] */,
 					       enum DNS_RPC_TYPEID _dwTypeId /* [in]  */,
 					       union DNSSRV_RPC_UNION _pData /* [in] [switch_is(dwTypeId)] */);
 NTSTATUS dcerpc_DnssrvOperation_recv(struct tevent_req *req,
@@ -25,10 +25,10 @@ NTSTATUS dcerpc_DnssrvOperation_recv(struct tevent_req *req,
 				     WERROR *result);
 NTSTATUS dcerpc_DnssrvOperation(struct dcerpc_binding_handle *h,
 				TALLOC_CTX *mem_ctx,
-				const char *_pwszServerName /* [in] [charset(UTF16),unique] */,
-				const char *_pszZone /* [in] [unique,charset(UTF8)] */,
+				const char *_pwszServerName /* [in] [unique,charset(UTF16)] */,
+				const char *_pszZone /* [in] [charset(UTF8),unique] */,
 				uint32_t _dwContext /* [in]  */,
-				const char *_pszOperation /* [in] [charset(UTF8),unique] */,
+				const char *_pszOperation /* [in] [unique,charset(UTF8)] */,
 				enum DNS_RPC_TYPEID _dwTypeId /* [in]  */,
 				union DNSSRV_RPC_UNION _pData /* [in] [switch_is(dwTypeId)] */,
 				WERROR *result);
@@ -42,8 +42,8 @@ NTSTATUS dcerpc_DnssrvQuery_r(struct dcerpc_binding_handle *h, TALLOC_CTX *mem_c
 struct tevent_req *dcerpc_DnssrvQuery_send(TALLOC_CTX *mem_ctx,
 					   struct tevent_context *ev,
 					   struct dcerpc_binding_handle *h,
-					   const char *_pwszServerName /* [in] [charset(UTF16),unique] */,
-					   const char *_pszZone /* [in] [charset(UTF8),unique] */,
+					   const char *_pwszServerName /* [in] [unique,charset(UTF16)] */,
+					   const char *_pszZone /* [in] [unique,charset(UTF8)] */,
 					   const char *_pszOperation /* [in] [charset(UTF8),unique] */,
 					   enum DNS_RPC_TYPEID *_pdwTypeId /* [out] [ref] */,
 					   union DNSSRV_RPC_UNION *_ppData /* [out] [switch_is(*pdwTypeId),ref] */);
@@ -52,8 +52,8 @@ NTSTATUS dcerpc_DnssrvQuery_recv(struct tevent_req *req,
 				 WERROR *result);
 NTSTATUS dcerpc_DnssrvQuery(struct dcerpc_binding_handle *h,
 			    TALLOC_CTX *mem_ctx,
-			    const char *_pwszServerName /* [in] [charset(UTF16),unique] */,
-			    const char *_pszZone /* [in] [charset(UTF8),unique] */,
+			    const char *_pwszServerName /* [in] [unique,charset(UTF16)] */,
+			    const char *_pszZone /* [in] [unique,charset(UTF8)] */,
 			    const char *_pszOperation /* [in] [charset(UTF8),unique] */,
 			    enum DNS_RPC_TYPEID *_pdwTypeId /* [out] [ref] */,
 			    union DNSSRV_RPC_UNION *_ppData /* [out] [switch_is(*pdwTypeId),ref] */,
@@ -68,25 +68,25 @@ NTSTATUS dcerpc_DnssrvComplexOperation_r(struct dcerpc_binding_handle *h, TALLOC
 struct tevent_req *dcerpc_DnssrvComplexOperation_send(TALLOC_CTX *mem_ctx,
 						      struct tevent_context *ev,
 						      struct dcerpc_binding_handle *h,
-						      const char *_pwszServerName /* [in] [unique,charset(UTF16)] */,
-						      const char *_pszZone /* [in] [charset(UTF8),unique] */,
+						      const char *_pwszServerName /* [in] [charset(UTF16),unique] */,
+						      const char *_pszZone /* [in] [unique,charset(UTF8)] */,
 						      const char *_pszOperation /* [in] [charset(UTF8),unique] */,
 						      enum DNS_RPC_TYPEID _dwTypeIn /* [in]  */,
 						      union DNSSRV_RPC_UNION _pDataIn /* [in] [switch_is(dwTypeIn)] */,
 						      enum DNS_RPC_TYPEID *_pdwTypeOut /* [out] [ref] */,
-						      union DNSSRV_RPC_UNION *_ppDataOut /* [out] [switch_is(*pdwTypeOut),ref] */);
+						      union DNSSRV_RPC_UNION *_ppDataOut /* [out] [ref,switch_is(*pdwTypeOut)] */);
 NTSTATUS dcerpc_DnssrvComplexOperation_recv(struct tevent_req *req,
 					    TALLOC_CTX *mem_ctx,
 					    WERROR *result);
 NTSTATUS dcerpc_DnssrvComplexOperation(struct dcerpc_binding_handle *h,
 				       TALLOC_CTX *mem_ctx,
-				       const char *_pwszServerName /* [in] [unique,charset(UTF16)] */,
-				       const char *_pszZone /* [in] [charset(UTF8),unique] */,
+				       const char *_pwszServerName /* [in] [charset(UTF16),unique] */,
+				       const char *_pszZone /* [in] [unique,charset(UTF8)] */,
 				       const char *_pszOperation /* [in] [charset(UTF8),unique] */,
 				       enum DNS_RPC_TYPEID _dwTypeIn /* [in]  */,
 				       union DNSSRV_RPC_UNION _pDataIn /* [in] [switch_is(dwTypeIn)] */,
 				       enum DNS_RPC_TYPEID *_pdwTypeOut /* [out] [ref] */,
-				       union DNSSRV_RPC_UNION *_ppDataOut /* [out] [switch_is(*pdwTypeOut),ref] */,
+				       union DNSSRV_RPC_UNION *_ppDataOut /* [out] [ref,switch_is(*pdwTypeOut)] */,
 				       WERROR *result);
 
 struct tevent_req *dcerpc_DnssrvEnumRecords_r_send(TALLOC_CTX *mem_ctx,
@@ -99,30 +99,30 @@ struct tevent_req *dcerpc_DnssrvEnumRecords_send(TALLOC_CTX *mem_ctx,
 						 struct tevent_context *ev,
 						 struct dcerpc_binding_handle *h,
 						 const char *_pwszServerName /* [in] [charset(UTF16),unique] */,
-						 const char *_pszZone /* [in] [charset(UTF8),unique] */,
+						 const char *_pszZone /* [in] [unique,charset(UTF8)] */,
 						 const char *_pszNodeName /* [in] [unique,charset(UTF8)] */,
-						 const char *_pszStartChild /* [in] [unique,charset(UTF8)] */,
+						 const char *_pszStartChild /* [in] [charset(UTF8),unique] */,
 						 enum dns_record_type _wRecordType /* [in]  */,
 						 uint32_t _fSelectFlag /* [in]  */,
-						 const char *_pszFilterStart /* [in] [unique,charset(UTF8)] */,
+						 const char *_pszFilterStart /* [in] [charset(UTF8),unique] */,
 						 const char *_pszFilterStop /* [in] [unique,charset(UTF8)] */,
 						 uint32_t *_pdwBufferLength /* [out] [ref] */,
-						 struct DNS_RPC_RECORDS_ARRAY **_pBuffer /* [out] [ref,subcontext_size(*pdwBufferLength),subcontext(4)] */);
+						 struct DNS_RPC_RECORDS_ARRAY **_pBuffer /* [out] [subcontext_size(*pdwBufferLength),subcontext(4),ref] */);
 NTSTATUS dcerpc_DnssrvEnumRecords_recv(struct tevent_req *req,
 				       TALLOC_CTX *mem_ctx,
 				       WERROR *result);
 NTSTATUS dcerpc_DnssrvEnumRecords(struct dcerpc_binding_handle *h,
 				  TALLOC_CTX *mem_ctx,
 				  const char *_pwszServerName /* [in] [charset(UTF16),unique] */,
-				  const char *_pszZone /* [in] [charset(UTF8),unique] */,
+				  const char *_pszZone /* [in] [unique,charset(UTF8)] */,
 				  const char *_pszNodeName /* [in] [unique,charset(UTF8)] */,
-				  const char *_pszStartChild /* [in] [unique,charset(UTF8)] */,
+				  const char *_pszStartChild /* [in] [charset(UTF8),unique] */,
 				  enum dns_record_type _wRecordType /* [in]  */,
 				  uint32_t _fSelectFlag /* [in]  */,
-				  const char *_pszFilterStart /* [in] [unique,charset(UTF8)] */,
+				  const char *_pszFilterStart /* [in] [charset(UTF8),unique] */,
 				  const char *_pszFilterStop /* [in] [unique,charset(UTF8)] */,
 				  uint32_t *_pdwBufferLength /* [out] [ref] */,
-				  struct DNS_RPC_RECORDS_ARRAY **_pBuffer /* [out] [ref,subcontext_size(*pdwBufferLength),subcontext(4)] */,
+				  struct DNS_RPC_RECORDS_ARRAY **_pBuffer /* [out] [subcontext_size(*pdwBufferLength),subcontext(4),ref] */,
 				  WERROR *result);
 
 struct tevent_req *dcerpc_DnssrvUpdateRecord_r_send(TALLOC_CTX *mem_ctx,
@@ -134,9 +134,9 @@ NTSTATUS dcerpc_DnssrvUpdateRecord_r(struct dcerpc_binding_handle *h, TALLOC_CTX
 struct tevent_req *dcerpc_DnssrvUpdateRecord_send(TALLOC_CTX *mem_ctx,
 						  struct tevent_context *ev,
 						  struct dcerpc_binding_handle *h,
-						  const char *_pwszServerName /* [in] [charset(UTF16),unique] */,
+						  const char *_pwszServerName /* [in] [unique,charset(UTF16)] */,
 						  const char *_pszZone /* [in] [unique,charset(UTF8)] */,
-						  const char *_pszNodeName /* [in] [charset(UTF8),unique] */,
+						  const char *_pszNodeName /* [in] [unique,charset(UTF8)] */,
 						  struct DNS_RPC_RECORD_BUF *_pAddRecord /* [in] [unique] */,
 						  struct DNS_RPC_RECORD_BUF *_pDeleteRecord /* [in] [unique] */);
 NTSTATUS dcerpc_DnssrvUpdateRecord_recv(struct tevent_req *req,
@@ -144,9 +144,9 @@ NTSTATUS dcerpc_DnssrvUpdateRecord_recv(struct tevent_req *req,
 					WERROR *result);
 NTSTATUS dcerpc_DnssrvUpdateRecord(struct dcerpc_binding_handle *h,
 				   TALLOC_CTX *mem_ctx,
-				   const char *_pwszServerName /* [in] [charset(UTF16),unique] */,
+				   const char *_pwszServerName /* [in] [unique,charset(UTF16)] */,
 				   const char *_pszZone /* [in] [unique,charset(UTF8)] */,
-				   const char *_pszNodeName /* [in] [charset(UTF8),unique] */,
+				   const char *_pszNodeName /* [in] [unique,charset(UTF8)] */,
 				   struct DNS_RPC_RECORD_BUF *_pAddRecord /* [in] [unique] */,
 				   struct DNS_RPC_RECORD_BUF *_pDeleteRecord /* [in] [unique] */,
 				   WERROR *result);
@@ -165,7 +165,7 @@ struct tevent_req *dcerpc_DnssrvOperation2_send(TALLOC_CTX *mem_ctx,
 						const char *_pwszServerName /* [in] [unique,charset(UTF16)] */,
 						const char *_pszZone /* [in] [unique,charset(UTF8)] */,
 						uint32_t _dwContext /* [in]  */,
-						const char *_pszOperation /* [in] [charset(UTF8),unique] */,
+						const char *_pszOperation /* [in] [unique,charset(UTF8)] */,
 						enum DNS_RPC_TYPEID _dwTypeId /* [in]  */,
 						union DNSSRV_RPC_UNION _pData /* [in] [switch_is(dwTypeId)] */);
 NTSTATUS dcerpc_DnssrvOperation2_recv(struct tevent_req *req,
@@ -178,7 +178,7 @@ NTSTATUS dcerpc_DnssrvOperation2(struct dcerpc_binding_handle *h,
 				 const char *_pwszServerName /* [in] [unique,charset(UTF16)] */,
 				 const char *_pszZone /* [in] [unique,charset(UTF8)] */,
 				 uint32_t _dwContext /* [in]  */,
-				 const char *_pszOperation /* [in] [charset(UTF8),unique] */,
+				 const char *_pszOperation /* [in] [unique,charset(UTF8)] */,
 				 enum DNS_RPC_TYPEID _dwTypeId /* [in]  */,
 				 union DNSSRV_RPC_UNION _pData /* [in] [switch_is(dwTypeId)] */,
 				 WERROR *result);
@@ -195,10 +195,10 @@ struct tevent_req *dcerpc_DnssrvQuery2_send(TALLOC_CTX *mem_ctx,
 					    enum DNS_RPC_CLIENT_VERSION _dwClientVersion /* [in]  */,
 					    uint32_t _dwSettingFlags /* [in]  */,
 					    const char *_pwszServerName /* [in] [unique,charset(UTF16)] */,
-					    const char *_pszZone /* [in] [unique,charset(UTF8)] */,
+					    const char *_pszZone /* [in] [charset(UTF8),unique] */,
 					    const char *_pszOperation /* [in] [charset(UTF8),unique] */,
 					    enum DNS_RPC_TYPEID *_pdwTypeId /* [out] [ref] */,
-					    union DNSSRV_RPC_UNION *_ppData /* [out] [ref,switch_is(*pdwTypeId)] */);
+					    union DNSSRV_RPC_UNION *_ppData /* [out] [switch_is(*pdwTypeId),ref] */);
 NTSTATUS dcerpc_DnssrvQuery2_recv(struct tevent_req *req,
 				  TALLOC_CTX *mem_ctx,
 				  WERROR *result);
@@ -207,10 +207,10 @@ NTSTATUS dcerpc_DnssrvQuery2(struct dcerpc_binding_handle *h,
 			     enum DNS_RPC_CLIENT_VERSION _dwClientVersion /* [in]  */,
 			     uint32_t _dwSettingFlags /* [in]  */,
 			     const char *_pwszServerName /* [in] [unique,charset(UTF16)] */,
-			     const char *_pszZone /* [in] [unique,charset(UTF8)] */,
+			     const char *_pszZone /* [in] [charset(UTF8),unique] */,
 			     const char *_pszOperation /* [in] [charset(UTF8),unique] */,
 			     enum DNS_RPC_TYPEID *_pdwTypeId /* [out] [ref] */,
-			     union DNSSRV_RPC_UNION *_ppData /* [out] [ref,switch_is(*pdwTypeId)] */,
+			     union DNSSRV_RPC_UNION *_ppData /* [out] [switch_is(*pdwTypeId),ref] */,
 			     WERROR *result);
 
 struct tevent_req *dcerpc_DnssrvComplexOperation2_r_send(TALLOC_CTX *mem_ctx,
@@ -230,7 +230,7 @@ struct tevent_req *dcerpc_DnssrvComplexOperation2_send(TALLOC_CTX *mem_ctx,
 						       enum DNS_RPC_TYPEID _dwTypeIn /* [in]  */,
 						       union DNSSRV_RPC_UNION _pDataIn /* [in] [switch_is(dwTypeIn)] */,
 						       enum DNS_RPC_TYPEID *_pdwTypeOut /* [out] [ref] */,
-						       union DNSSRV_RPC_UNION *_ppDataOut /* [out] [switch_is(*pdwTypeOut),ref] */);
+						       union DNSSRV_RPC_UNION *_ppDataOut /* [out] [ref,switch_is(*pdwTypeOut)] */);
 NTSTATUS dcerpc_DnssrvComplexOperation2_recv(struct tevent_req *req,
 					     TALLOC_CTX *mem_ctx,
 					     WERROR *result);
@@ -244,7 +244,7 @@ NTSTATUS dcerpc_DnssrvComplexOperation2(struct dcerpc_binding_handle *h,
 					enum DNS_RPC_TYPEID _dwTypeIn /* [in]  */,
 					union DNSSRV_RPC_UNION _pDataIn /* [in] [switch_is(dwTypeIn)] */,
 					enum DNS_RPC_TYPEID *_pdwTypeOut /* [out] [ref] */,
-					union DNSSRV_RPC_UNION *_ppDataOut /* [out] [switch_is(*pdwTypeOut),ref] */,
+					union DNSSRV_RPC_UNION *_ppDataOut /* [out] [ref,switch_is(*pdwTypeOut)] */,
 					WERROR *result);
 
 struct tevent_req *dcerpc_DnssrvEnumRecords2_r_send(TALLOC_CTX *mem_ctx,
@@ -260,14 +260,14 @@ struct tevent_req *dcerpc_DnssrvEnumRecords2_send(TALLOC_CTX *mem_ctx,
 						  uint32_t _dwSettingFlags /* [in]  */,
 						  const char *_pwszServerName /* [in] [unique,charset(UTF16)] */,
 						  const char *_pszZone /* [in] [charset(UTF8),unique] */,
-						  const char *_pszNodeName /* [in] [unique,charset(UTF8)] */,
+						  const char *_pszNodeName /* [in] [charset(UTF8),unique] */,
 						  const char *_pszStartChild /* [in] [unique,charset(UTF8)] */,
 						  enum dns_record_type _wRecordType /* [in]  */,
 						  uint32_t _fSelectFlag /* [in]  */,
-						  const char *_pszFilterStart /* [in] [unique,charset(UTF8)] */,
-						  const char *_pszFilterStop /* [in] [charset(UTF8),unique] */,
+						  const char *_pszFilterStart /* [in] [charset(UTF8),unique] */,
+						  const char *_pszFilterStop /* [in] [unique,charset(UTF8)] */,
 						  uint32_t *_pdwBufferLength /* [out] [ref] */,
-						  struct DNS_RPC_RECORDS_ARRAY **_pBuffer /* [out] [subcontext_size(*pdwBufferLength),ref,subcontext(4)] */);
+						  struct DNS_RPC_RECORDS_ARRAY **_pBuffer /* [out] [subcontext(4),ref,subcontext_size(*pdwBufferLength)] */);
 NTSTATUS dcerpc_DnssrvEnumRecords2_recv(struct tevent_req *req,
 					TALLOC_CTX *mem_ctx,
 					WERROR *result);
@@ -277,14 +277,14 @@ NTSTATUS dcerpc_DnssrvEnumRecords2(struct dcerpc_binding_handle *h,
 				   uint32_t _dwSettingFlags /* [in]  */,
 				   const char *_pwszServerName /* [in] [unique,charset(UTF16)] */,
 				   const char *_pszZone /* [in] [charset(UTF8),unique] */,
-				   const char *_pszNodeName /* [in] [unique,charset(UTF8)] */,
+				   const char *_pszNodeName /* [in] [charset(UTF8),unique] */,
 				   const char *_pszStartChild /* [in] [unique,charset(UTF8)] */,
 				   enum dns_record_type _wRecordType /* [in]  */,
 				   uint32_t _fSelectFlag /* [in]  */,
-				   const char *_pszFilterStart /* [in] [unique,charset(UTF8)] */,
-				   const char *_pszFilterStop /* [in] [charset(UTF8),unique] */,
+				   const char *_pszFilterStart /* [in] [charset(UTF8),unique] */,
+				   const char *_pszFilterStop /* [in] [unique,charset(UTF8)] */,
 				   uint32_t *_pdwBufferLength /* [out] [ref] */,
-				   struct DNS_RPC_RECORDS_ARRAY **_pBuffer /* [out] [subcontext_size(*pdwBufferLength),ref,subcontext(4)] */,
+				   struct DNS_RPC_RECORDS_ARRAY **_pBuffer /* [out] [subcontext(4),ref,subcontext_size(*pdwBufferLength)] */,
 				   WERROR *result);
 
 struct tevent_req *dcerpc_DnssrvUpdateRecord2_r_send(TALLOC_CTX *mem_ctx,
@@ -298,9 +298,9 @@ struct tevent_req *dcerpc_DnssrvUpdateRecord2_send(TALLOC_CTX *mem_ctx,
 						   struct dcerpc_binding_handle *h,
 						   enum DNS_RPC_CLIENT_VERSION _dwClientVersion /* [in]  */,
 						   uint32_t _dwSettingFlags /* [in]  */,
-						   const char *_pwszServerName /* [in] [charset(UTF16),unique] */,
-						   const char *_pszZone /* [in] [charset(UTF8),unique] */,
-						   const char *_pszNodeName /* [in] [charset(UTF8),ref] */,
+						   const char *_pwszServerName /* [in] [unique,charset(UTF16)] */,
+						   const char *_pszZone /* [in] [unique,charset(UTF8)] */,
+						   const char *_pszNodeName /* [in] [ref,charset(UTF8)] */,
 						   struct DNS_RPC_RECORD_BUF *_pAddRecord /* [in] [unique] */,
 						   struct DNS_RPC_RECORD_BUF *_pDeleteRecord /* [in] [unique] */);
 NTSTATUS dcerpc_DnssrvUpdateRecord2_recv(struct tevent_req *req,
@@ -310,9 +310,9 @@ NTSTATUS dcerpc_DnssrvUpdateRecord2(struct dcerpc_binding_handle *h,
 				    TALLOC_CTX *mem_ctx,
 				    enum DNS_RPC_CLIENT_VERSION _dwClientVersion /* [in]  */,
 				    uint32_t _dwSettingFlags /* [in]  */,
-				    const char *_pwszServerName /* [in] [charset(UTF16),unique] */,
-				    const char *_pszZone /* [in] [charset(UTF8),unique] */,
-				    const char *_pszNodeName /* [in] [charset(UTF8),ref] */,
+				    const char *_pwszServerName /* [in] [unique,charset(UTF16)] */,
+				    const char *_pszZone /* [in] [unique,charset(UTF8)] */,
+				    const char *_pszNodeName /* [in] [ref,charset(UTF8)] */,
 				    struct DNS_RPC_RECORD_BUF *_pAddRecord /* [in] [unique] */,
 				    struct DNS_RPC_RECORD_BUF *_pDeleteRecord /* [in] [unique] */,
 				    WERROR *result);
