@@ -56,7 +56,7 @@ struct tevent_req *dcerpc_drsuapi_DsReplicaSync_send(TALLOC_CTX *mem_ctx,
 						     struct dcerpc_binding_handle *h,
 						     struct policy_handle *_bind_handle /* [in] [ref] */,
 						     uint32_t _level /* [in]  */,
-						     union drsuapi_DsReplicaSyncRequest *_req /* [in] [ref,switch_is(level)] */);
+						     union drsuapi_DsReplicaSyncRequest *_req /* [in] [switch_is(level),ref] */);
 NTSTATUS dcerpc_drsuapi_DsReplicaSync_recv(struct tevent_req *req,
 					   TALLOC_CTX *mem_ctx,
 					   WERROR *result);
@@ -64,7 +64,7 @@ NTSTATUS dcerpc_drsuapi_DsReplicaSync(struct dcerpc_binding_handle *h,
 				      TALLOC_CTX *mem_ctx,
 				      struct policy_handle *_bind_handle /* [in] [ref] */,
 				      uint32_t _level /* [in]  */,
-				      union drsuapi_DsReplicaSyncRequest *_req /* [in] [ref,switch_is(level)] */,
+				      union drsuapi_DsReplicaSyncRequest *_req /* [in] [switch_is(level),ref] */,
 				      WERROR *result);
 
 struct tevent_req *dcerpc_drsuapi_DsGetNCChanges_r_send(TALLOC_CTX *mem_ctx,
@@ -80,7 +80,7 @@ struct tevent_req *dcerpc_drsuapi_DsGetNCChanges_send(TALLOC_CTX *mem_ctx,
 						      uint32_t _level /* [in]  */,
 						      union drsuapi_DsGetNCChangesRequest *_req /* [in] [switch_is(level),ref] */,
 						      uint32_t *_level_out /* [out] [ref] */,
-						      union drsuapi_DsGetNCChangesCtr *_ctr /* [out] [ref,switch_is(*level_out)] */);
+						      union drsuapi_DsGetNCChangesCtr *_ctr /* [out] [switch_is(*level_out),ref] */);
 NTSTATUS dcerpc_drsuapi_DsGetNCChanges_recv(struct tevent_req *req,
 					    TALLOC_CTX *mem_ctx,
 					    WERROR *result);
@@ -90,7 +90,7 @@ NTSTATUS dcerpc_drsuapi_DsGetNCChanges(struct dcerpc_binding_handle *h,
 				       uint32_t _level /* [in]  */,
 				       union drsuapi_DsGetNCChangesRequest *_req /* [in] [switch_is(level),ref] */,
 				       uint32_t *_level_out /* [out] [ref] */,
-				       union drsuapi_DsGetNCChangesCtr *_ctr /* [out] [ref,switch_is(*level_out)] */,
+				       union drsuapi_DsGetNCChangesCtr *_ctr /* [out] [switch_is(*level_out),ref] */,
 				       WERROR *result);
 
 struct tevent_req *dcerpc_drsuapi_DsReplicaUpdateRefs_r_send(TALLOC_CTX *mem_ctx,
@@ -192,9 +192,9 @@ struct tevent_req *dcerpc_drsuapi_DsGetMemberships_send(TALLOC_CTX *mem_ctx,
 							struct dcerpc_binding_handle *h,
 							struct policy_handle *_bind_handle /* [in] [ref] */,
 							uint32_t _level /* [in]  */,
-							union drsuapi_DsGetMembershipsRequest *_req /* [in] [switch_is(level),ref] */,
+							union drsuapi_DsGetMembershipsRequest *_req /* [in] [ref,switch_is(level)] */,
 							uint32_t *_level_out /* [out] [ref] */,
-							union drsuapi_DsGetMembershipsCtr *_ctr /* [out] [switch_is(*level_out),ref] */);
+							union drsuapi_DsGetMembershipsCtr *_ctr /* [out] [ref,switch_is(*level_out)] */);
 NTSTATUS dcerpc_drsuapi_DsGetMemberships_recv(struct tevent_req *req,
 					      TALLOC_CTX *mem_ctx,
 					      WERROR *result);
@@ -202,9 +202,9 @@ NTSTATUS dcerpc_drsuapi_DsGetMemberships(struct dcerpc_binding_handle *h,
 					 TALLOC_CTX *mem_ctx,
 					 struct policy_handle *_bind_handle /* [in] [ref] */,
 					 uint32_t _level /* [in]  */,
-					 union drsuapi_DsGetMembershipsRequest *_req /* [in] [switch_is(level),ref] */,
+					 union drsuapi_DsGetMembershipsRequest *_req /* [in] [ref,switch_is(level)] */,
 					 uint32_t *_level_out /* [out] [ref] */,
-					 union drsuapi_DsGetMembershipsCtr *_ctr /* [out] [switch_is(*level_out),ref] */,
+					 union drsuapi_DsGetMembershipsCtr *_ctr /* [out] [ref,switch_is(*level_out)] */,
 					 WERROR *result);
 
 struct tevent_req *dcerpc_drsuapi_DsGetNT4ChangeLog_r_send(TALLOC_CTX *mem_ctx,
@@ -218,7 +218,7 @@ struct tevent_req *dcerpc_drsuapi_DsGetNT4ChangeLog_send(TALLOC_CTX *mem_ctx,
 							 struct dcerpc_binding_handle *h,
 							 struct policy_handle *_bind_handle /* [in] [ref] */,
 							 uint32_t _level /* [in]  */,
-							 union drsuapi_DsGetNT4ChangeLogRequest *_req /* [in] [switch_is(level),ref] */,
+							 union drsuapi_DsGetNT4ChangeLogRequest *_req /* [in] [ref,switch_is(level)] */,
 							 uint32_t *_level_out /* [out] [ref] */,
 							 union drsuapi_DsGetNT4ChangeLogInfo *_info /* [out] [ref,switch_is(*level_out)] */);
 NTSTATUS dcerpc_drsuapi_DsGetNT4ChangeLog_recv(struct tevent_req *req,
@@ -228,7 +228,7 @@ NTSTATUS dcerpc_drsuapi_DsGetNT4ChangeLog(struct dcerpc_binding_handle *h,
 					  TALLOC_CTX *mem_ctx,
 					  struct policy_handle *_bind_handle /* [in] [ref] */,
 					  uint32_t _level /* [in]  */,
-					  union drsuapi_DsGetNT4ChangeLogRequest *_req /* [in] [switch_is(level),ref] */,
+					  union drsuapi_DsGetNT4ChangeLogRequest *_req /* [in] [ref,switch_is(level)] */,
 					  uint32_t *_level_out /* [out] [ref] */,
 					  union drsuapi_DsGetNT4ChangeLogInfo *_info /* [out] [ref,switch_is(*level_out)] */,
 					  WERROR *result);
@@ -244,9 +244,9 @@ struct tevent_req *dcerpc_drsuapi_DsCrackNames_send(TALLOC_CTX *mem_ctx,
 						    struct dcerpc_binding_handle *h,
 						    struct policy_handle *_bind_handle /* [in] [ref] */,
 						    uint32_t _level /* [in]  */,
-						    union drsuapi_DsNameRequest *_req /* [in] [switch_is(level),ref] */,
+						    union drsuapi_DsNameRequest *_req /* [in] [ref,switch_is(level)] */,
 						    uint32_t *_level_out /* [out] [ref] */,
-						    union drsuapi_DsNameCtr *_ctr /* [out] [switch_is(*level_out),ref] */);
+						    union drsuapi_DsNameCtr *_ctr /* [out] [ref,switch_is(*level_out)] */);
 NTSTATUS dcerpc_drsuapi_DsCrackNames_recv(struct tevent_req *req,
 					  TALLOC_CTX *mem_ctx,
 					  WERROR *result);
@@ -254,9 +254,9 @@ NTSTATUS dcerpc_drsuapi_DsCrackNames(struct dcerpc_binding_handle *h,
 				     TALLOC_CTX *mem_ctx,
 				     struct policy_handle *_bind_handle /* [in] [ref] */,
 				     uint32_t _level /* [in]  */,
-				     union drsuapi_DsNameRequest *_req /* [in] [switch_is(level),ref] */,
+				     union drsuapi_DsNameRequest *_req /* [in] [ref,switch_is(level)] */,
 				     uint32_t *_level_out /* [out] [ref] */,
-				     union drsuapi_DsNameCtr *_ctr /* [out] [switch_is(*level_out),ref] */,
+				     union drsuapi_DsNameCtr *_ctr /* [out] [ref,switch_is(*level_out)] */,
 				     WERROR *result);
 
 struct tevent_req *dcerpc_drsuapi_DsWriteAccountSpn_r_send(TALLOC_CTX *mem_ctx,
@@ -296,9 +296,9 @@ struct tevent_req *dcerpc_drsuapi_DsRemoveDSServer_send(TALLOC_CTX *mem_ctx,
 							struct dcerpc_binding_handle *h,
 							struct policy_handle *_bind_handle /* [in] [ref] */,
 							uint32_t _level /* [in]  */,
-							union drsuapi_DsRemoveDSServerRequest *_req /* [in] [switch_is(level),ref] */,
+							union drsuapi_DsRemoveDSServerRequest *_req /* [in] [ref,switch_is(level)] */,
 							uint32_t *_level_out /* [out] [ref] */,
-							union drsuapi_DsRemoveDSServerResult *_res /* [out] [switch_is(*level_out),ref] */);
+							union drsuapi_DsRemoveDSServerResult *_res /* [out] [ref,switch_is(*level_out)] */);
 NTSTATUS dcerpc_drsuapi_DsRemoveDSServer_recv(struct tevent_req *req,
 					      TALLOC_CTX *mem_ctx,
 					      WERROR *result);
@@ -306,9 +306,9 @@ NTSTATUS dcerpc_drsuapi_DsRemoveDSServer(struct dcerpc_binding_handle *h,
 					 TALLOC_CTX *mem_ctx,
 					 struct policy_handle *_bind_handle /* [in] [ref] */,
 					 uint32_t _level /* [in]  */,
-					 union drsuapi_DsRemoveDSServerRequest *_req /* [in] [switch_is(level),ref] */,
+					 union drsuapi_DsRemoveDSServerRequest *_req /* [in] [ref,switch_is(level)] */,
 					 uint32_t *_level_out /* [out] [ref] */,
-					 union drsuapi_DsRemoveDSServerResult *_res /* [out] [switch_is(*level_out),ref] */,
+					 union drsuapi_DsRemoveDSServerResult *_res /* [out] [ref,switch_is(*level_out)] */,
 					 WERROR *result);
 
 struct tevent_req *dcerpc_drsuapi_DsGetDomainControllerInfo_r_send(TALLOC_CTX *mem_ctx,
@@ -324,7 +324,7 @@ struct tevent_req *dcerpc_drsuapi_DsGetDomainControllerInfo_send(TALLOC_CTX *mem
 								 int32_t _level /* [in]  */,
 								 union drsuapi_DsGetDCInfoRequest *_req /* [in] [switch_is(level),ref] */,
 								 int32_t *_level_out /* [out] [ref] */,
-								 union drsuapi_DsGetDCInfoCtr *_ctr /* [out] [ref,switch_is(*level_out)] */);
+								 union drsuapi_DsGetDCInfoCtr *_ctr /* [out] [switch_is(*level_out),ref] */);
 NTSTATUS dcerpc_drsuapi_DsGetDomainControllerInfo_recv(struct tevent_req *req,
 						       TALLOC_CTX *mem_ctx,
 						       WERROR *result);
@@ -334,7 +334,7 @@ NTSTATUS dcerpc_drsuapi_DsGetDomainControllerInfo(struct dcerpc_binding_handle *
 						  int32_t _level /* [in]  */,
 						  union drsuapi_DsGetDCInfoRequest *_req /* [in] [switch_is(level),ref] */,
 						  int32_t *_level_out /* [out] [ref] */,
-						  union drsuapi_DsGetDCInfoCtr *_ctr /* [out] [ref,switch_is(*level_out)] */,
+						  union drsuapi_DsGetDCInfoCtr *_ctr /* [out] [switch_is(*level_out),ref] */,
 						  WERROR *result);
 
 struct tevent_req *dcerpc_drsuapi_DsAddEntry_r_send(TALLOC_CTX *mem_ctx,
@@ -374,7 +374,7 @@ struct tevent_req *dcerpc_drsuapi_DsExecuteKCC_send(TALLOC_CTX *mem_ctx,
 						    struct dcerpc_binding_handle *h,
 						    struct policy_handle *_bind_handle /* [in] [ref] */,
 						    uint32_t _level /* [in]  */,
-						    union drsuapi_DsExecuteKCCRequest *_req /* [in] [switch_is(level),ref] */);
+						    union drsuapi_DsExecuteKCCRequest *_req /* [in] [ref,switch_is(level)] */);
 NTSTATUS dcerpc_drsuapi_DsExecuteKCC_recv(struct tevent_req *req,
 					  TALLOC_CTX *mem_ctx,
 					  WERROR *result);
@@ -382,7 +382,7 @@ NTSTATUS dcerpc_drsuapi_DsExecuteKCC(struct dcerpc_binding_handle *h,
 				     TALLOC_CTX *mem_ctx,
 				     struct policy_handle *_bind_handle /* [in] [ref] */,
 				     uint32_t _level /* [in]  */,
-				     union drsuapi_DsExecuteKCCRequest *_req /* [in] [switch_is(level),ref] */,
+				     union drsuapi_DsExecuteKCCRequest *_req /* [in] [ref,switch_is(level)] */,
 				     WERROR *result);
 
 struct tevent_req *dcerpc_drsuapi_DsReplicaGetInfo_r_send(TALLOC_CTX *mem_ctx,
@@ -424,7 +424,7 @@ struct tevent_req *dcerpc_drsuapi_DsGetMemberships2_send(TALLOC_CTX *mem_ctx,
 							 uint32_t _level /* [in]  */,
 							 union drsuapi_DsGetMemberships2Request *_req /* [in] [ref,switch_is(level)] */,
 							 uint32_t *_level_out /* [out] [ref] */,
-							 union drsuapi_DsGetMemberships2Ctr *_ctr /* [out] [switch_is(*level_out),ref] */);
+							 union drsuapi_DsGetMemberships2Ctr *_ctr /* [out] [ref,switch_is(*level_out)] */);
 NTSTATUS dcerpc_drsuapi_DsGetMemberships2_recv(struct tevent_req *req,
 					       TALLOC_CTX *mem_ctx,
 					       WERROR *result);
@@ -434,7 +434,7 @@ NTSTATUS dcerpc_drsuapi_DsGetMemberships2(struct dcerpc_binding_handle *h,
 					  uint32_t _level /* [in]  */,
 					  union drsuapi_DsGetMemberships2Request *_req /* [in] [ref,switch_is(level)] */,
 					  uint32_t *_level_out /* [out] [ref] */,
-					  union drsuapi_DsGetMemberships2Ctr *_ctr /* [out] [switch_is(*level_out),ref] */,
+					  union drsuapi_DsGetMemberships2Ctr *_ctr /* [out] [ref,switch_is(*level_out)] */,
 					  WERROR *result);
 
 struct tevent_req *dcerpc_drsuapi_QuerySitesByCost_r_send(TALLOC_CTX *mem_ctx,
@@ -448,7 +448,7 @@ struct tevent_req *dcerpc_drsuapi_QuerySitesByCost_send(TALLOC_CTX *mem_ctx,
 							struct dcerpc_binding_handle *h,
 							struct policy_handle *_bind_handle /* [in] [ref] */,
 							uint32_t _level /* [in]  */,
-							union drsuapi_QuerySitesByCostRequest *_req /* [in] [switch_is(level),ref] */,
+							union drsuapi_QuerySitesByCostRequest *_req /* [in] [ref,switch_is(level)] */,
 							uint32_t *_level_out /* [out] [ref] */,
 							union drsuapi_QuerySitesByCostCtr *_ctr /* [out] [switch_is(*level_out),ref] */);
 NTSTATUS dcerpc_drsuapi_QuerySitesByCost_recv(struct tevent_req *req,
@@ -458,7 +458,7 @@ NTSTATUS dcerpc_drsuapi_QuerySitesByCost(struct dcerpc_binding_handle *h,
 					 TALLOC_CTX *mem_ctx,
 					 struct policy_handle *_bind_handle /* [in] [ref] */,
 					 uint32_t _level /* [in]  */,
-					 union drsuapi_QuerySitesByCostRequest *_req /* [in] [switch_is(level),ref] */,
+					 union drsuapi_QuerySitesByCostRequest *_req /* [in] [ref,switch_is(level)] */,
 					 uint32_t *_level_out /* [out] [ref] */,
 					 union drsuapi_QuerySitesByCostCtr *_ctr /* [out] [switch_is(*level_out),ref] */,
 					 WERROR *result);
