@@ -216,7 +216,7 @@ struct tevent_req *dcerpc_eventlog_ReadEventLogW_send(TALLOC_CTX *mem_ctx,
 						      uint32_t _flags /* [in]  */,
 						      uint32_t _offset /* [in]  */,
 						      uint32_t _number_of_bytes /* [in] [range(0,0x7FFFF)] */,
-						      uint8_t *_data /* [out] [size_is(number_of_bytes),ref] */,
+						      uint8_t *_data /* [out] [ref,size_is(number_of_bytes)] */,
 						      uint32_t *_sent_size /* [out] [ref] */,
 						      uint32_t *_real_size /* [out] [ref] */);
 NTSTATUS dcerpc_eventlog_ReadEventLogW_recv(struct tevent_req *req,
@@ -228,7 +228,7 @@ NTSTATUS dcerpc_eventlog_ReadEventLogW(struct dcerpc_binding_handle *h,
 				       uint32_t _flags /* [in]  */,
 				       uint32_t _offset /* [in]  */,
 				       uint32_t _number_of_bytes /* [in] [range(0,0x7FFFF)] */,
-				       uint8_t *_data /* [out] [size_is(number_of_bytes),ref] */,
+				       uint8_t *_data /* [out] [ref,size_is(number_of_bytes)] */,
 				       uint32_t *_sent_size /* [out] [ref] */,
 				       uint32_t *_real_size /* [out] [ref] */,
 				       NTSTATUS *result);
@@ -251,8 +251,8 @@ struct tevent_req *dcerpc_eventlog_ReportEventW_send(TALLOC_CTX *mem_ctx,
 						     uint32_t _data_size /* [in] [range(0,0x3FFFF)] */,
 						     struct lsa_String *_servername /* [in] [ref] */,
 						     struct dom_sid *_user_sid /* [in] [unique] */,
-						     struct lsa_String **_strings /* [in] [size_is(num_of_strings),unique] */,
-						     uint8_t *_data /* [in] [unique,size_is(data_size)] */,
+						     struct lsa_String **_strings /* [in] [unique,size_is(num_of_strings)] */,
+						     uint8_t *_data /* [in] [size_is(data_size),unique] */,
 						     uint16_t _flags /* [in]  */,
 						     uint32_t *_record_number /* [in,out] [unique] */,
 						     time_t *_time_written /* [in,out] [unique] */);
@@ -270,8 +270,8 @@ NTSTATUS dcerpc_eventlog_ReportEventW(struct dcerpc_binding_handle *h,
 				      uint32_t _data_size /* [in] [range(0,0x3FFFF)] */,
 				      struct lsa_String *_servername /* [in] [ref] */,
 				      struct dom_sid *_user_sid /* [in] [unique] */,
-				      struct lsa_String **_strings /* [in] [size_is(num_of_strings),unique] */,
-				      uint8_t *_data /* [in] [unique,size_is(data_size)] */,
+				      struct lsa_String **_strings /* [in] [unique,size_is(num_of_strings)] */,
+				      uint8_t *_data /* [in] [size_is(data_size),unique] */,
 				      uint16_t _flags /* [in]  */,
 				      uint32_t *_record_number /* [in,out] [unique] */,
 				      time_t *_time_written /* [in,out] [unique] */,
