@@ -32,7 +32,7 @@ NTSTATUS dcerpc_frsrpc_FrsVerifyPromotionParent_r(struct dcerpc_binding_handle *
 struct tevent_req *dcerpc_frsrpc_FrsVerifyPromotionParent_send(TALLOC_CTX *mem_ctx,
 							       struct tevent_context *ev,
 							       struct dcerpc_binding_handle *h,
-							       const char *_parent_account /* [in] [charset(UTF16),unique] */,
+							       const char *_parent_account /* [in] [unique,charset(UTF16)] */,
 							       const char *_parent_password /* [in] [unique,charset(UTF16)] */,
 							       const char *_replica_set_name /* [in] [charset(UTF16),unique] */,
 							       const char *_replica_set_type /* [in] [charset(UTF16),unique] */,
@@ -43,7 +43,7 @@ NTSTATUS dcerpc_frsrpc_FrsVerifyPromotionParent_recv(struct tevent_req *req,
 						     WERROR *result);
 NTSTATUS dcerpc_frsrpc_FrsVerifyPromotionParent(struct dcerpc_binding_handle *h,
 						TALLOC_CTX *mem_ctx,
-						const char *_parent_account /* [in] [charset(UTF16),unique] */,
+						const char *_parent_account /* [in] [unique,charset(UTF16)] */,
 						const char *_parent_password /* [in] [unique,charset(UTF16)] */,
 						const char *_replica_set_name /* [in] [charset(UTF16),unique] */,
 						const char *_replica_set_type /* [in] [charset(UTF16),unique] */,
@@ -61,16 +61,16 @@ struct tevent_req *dcerpc_frsrpc_FrsStartPromotionParent_send(TALLOC_CTX *mem_ct
 							      struct tevent_context *ev,
 							      struct dcerpc_binding_handle *h,
 							      const char *_parent_account /* [in] [charset(UTF16),unique] */,
-							      const char *_parent_password /* [in] [charset(UTF16),unique] */,
+							      const char *_parent_password /* [in] [unique,charset(UTF16)] */,
 							      const char *_replica_set_name /* [in] [unique,charset(UTF16)] */,
-							      const char *_replica_set_type /* [in] [charset(UTF16),unique] */,
-							      const char *_connection_name /* [in] [charset(UTF16),unique] */,
-							      const char *_partner_name /* [in] [charset(UTF16),unique] */,
-							      const char *_partner_princ_name /* [in] [unique,charset(UTF16)] */,
+							      const char *_replica_set_type /* [in] [unique,charset(UTF16)] */,
+							      const char *_connection_name /* [in] [unique,charset(UTF16)] */,
+							      const char *_partner_name /* [in] [unique,charset(UTF16)] */,
+							      const char *_partner_princ_name /* [in] [charset(UTF16),unique] */,
 							      enum frsrpc_PartnerAuthLevel _partner_auth_level /* [in]  */,
-							      uint32_t ___ndr_guid_size /* [in] [value(16),range(16,16)] */,
-							      struct GUID *_connection_guid /* [in] [unique,subcontext_size(16),subcontext(4)] */,
-							      struct GUID *_partner_guid /* [in] [subcontext(4),unique,subcontext_size(16)] */,
+							      uint32_t ___ndr_guid_size /* [in] [range(16,16),value(16)] */,
+							      struct GUID *_connection_guid /* [in] [subcontext(4),unique,subcontext_size(16)] */,
+							      struct GUID *_partner_guid /* [in] [subcontext_size(16),unique,subcontext(4)] */,
 							      struct GUID *_parent_guid /* [in,out] [subcontext_size(16),unique,subcontext(4)] */);
 NTSTATUS dcerpc_frsrpc_FrsStartPromotionParent_recv(struct tevent_req *req,
 						    TALLOC_CTX *mem_ctx,
@@ -78,16 +78,16 @@ NTSTATUS dcerpc_frsrpc_FrsStartPromotionParent_recv(struct tevent_req *req,
 NTSTATUS dcerpc_frsrpc_FrsStartPromotionParent(struct dcerpc_binding_handle *h,
 					       TALLOC_CTX *mem_ctx,
 					       const char *_parent_account /* [in] [charset(UTF16),unique] */,
-					       const char *_parent_password /* [in] [charset(UTF16),unique] */,
+					       const char *_parent_password /* [in] [unique,charset(UTF16)] */,
 					       const char *_replica_set_name /* [in] [unique,charset(UTF16)] */,
-					       const char *_replica_set_type /* [in] [charset(UTF16),unique] */,
-					       const char *_connection_name /* [in] [charset(UTF16),unique] */,
-					       const char *_partner_name /* [in] [charset(UTF16),unique] */,
-					       const char *_partner_princ_name /* [in] [unique,charset(UTF16)] */,
+					       const char *_replica_set_type /* [in] [unique,charset(UTF16)] */,
+					       const char *_connection_name /* [in] [unique,charset(UTF16)] */,
+					       const char *_partner_name /* [in] [unique,charset(UTF16)] */,
+					       const char *_partner_princ_name /* [in] [charset(UTF16),unique] */,
 					       enum frsrpc_PartnerAuthLevel _partner_auth_level /* [in]  */,
-					       uint32_t ___ndr_guid_size /* [in] [value(16),range(16,16)] */,
-					       struct GUID *_connection_guid /* [in] [unique,subcontext_size(16),subcontext(4)] */,
-					       struct GUID *_partner_guid /* [in] [subcontext(4),unique,subcontext_size(16)] */,
+					       uint32_t ___ndr_guid_size /* [in] [range(16,16),value(16)] */,
+					       struct GUID *_connection_guid /* [in] [subcontext(4),unique,subcontext_size(16)] */,
+					       struct GUID *_partner_guid /* [in] [subcontext_size(16),unique,subcontext(4)] */,
 					       struct GUID *_parent_guid /* [in,out] [subcontext_size(16),unique,subcontext(4)] */,
 					       WERROR *result);
 
