@@ -176,7 +176,7 @@ struct tevent_req *dcerpc_frstrans_InitializeFileTransferAsync_send(TALLOC_CTX *
 								    enum frstrans_RequestedStagingPolicy *_staging_policy /* [in,out] [ref] */,
 								    struct policy_handle *_server_context /* [out] [ref] */,
 								    struct frstrans_RdcFileInfo **_rdc_file_info /* [out] [ref] */,
-								    uint8_t *_data_buffer /* [out] [length_is(*size_read),size_is(buffer_size),ref] */,
+								    uint8_t *_data_buffer /* [out] [length_is(*size_read),ref,size_is(buffer_size)] */,
 								    uint32_t _buffer_size /* [in] [range(0,262144)] */,
 								    uint32_t *_size_read /* [out] [ref] */,
 								    uint32_t *_is_end_of_file /* [out] [ref] */);
@@ -191,7 +191,7 @@ NTSTATUS dcerpc_frstrans_InitializeFileTransferAsync(struct dcerpc_binding_handl
 						     enum frstrans_RequestedStagingPolicy *_staging_policy /* [in,out] [ref] */,
 						     struct policy_handle *_server_context /* [out] [ref] */,
 						     struct frstrans_RdcFileInfo **_rdc_file_info /* [out] [ref] */,
-						     uint8_t *_data_buffer /* [out] [length_is(*size_read),size_is(buffer_size),ref] */,
+						     uint8_t *_data_buffer /* [out] [length_is(*size_read),ref,size_is(buffer_size)] */,
 						     uint32_t _buffer_size /* [in] [range(0,262144)] */,
 						     uint32_t *_size_read /* [out] [ref] */,
 						     uint32_t *_is_end_of_file /* [out] [ref] */,
