@@ -76,7 +76,7 @@ struct tevent_req *dcerpc_fss_AddToShadowCopySet_send(TALLOC_CTX *mem_ctx,
 						      struct dcerpc_binding_handle *h,
 						      struct GUID _ClientShadowCopyId /* [in]  */,
 						      struct GUID _ShadowCopySetId /* [in]  */,
-						      const char *_ShareName /* [in] [ref,charset(UTF16)] */,
+						      const char *_ShareName /* [in] [charset(UTF16),ref] */,
 						      struct GUID *_pShadowCopyId /* [out] [ref] */);
 NTSTATUS dcerpc_fss_AddToShadowCopySet_recv(struct tevent_req *req,
 					    TALLOC_CTX *mem_ctx,
@@ -85,7 +85,7 @@ NTSTATUS dcerpc_fss_AddToShadowCopySet(struct dcerpc_binding_handle *h,
 				       TALLOC_CTX *mem_ctx,
 				       struct GUID _ClientShadowCopyId /* [in]  */,
 				       struct GUID _ShadowCopySetId /* [in]  */,
-				       const char *_ShareName /* [in] [ref,charset(UTF16)] */,
+				       const char *_ShareName /* [in] [charset(UTF16),ref] */,
 				       struct GUID *_pShadowCopyId /* [out] [ref] */,
 				       uint32_t *result);
 
@@ -174,19 +174,19 @@ NTSTATUS dcerpc_fss_IsPathSupported_r(struct dcerpc_binding_handle *h, TALLOC_CT
 struct tevent_req *dcerpc_fss_IsPathSupported_send(TALLOC_CTX *mem_ctx,
 						   struct tevent_context *ev,
 						   struct dcerpc_binding_handle *h,
-						   const char *_ShareName /* [in] [charset(UTF16),ref] */,
+						   const char *_ShareName /* [in] [ref,charset(UTF16)] */,
 						   uint8_t _magic[52] /* [in]  */,
 						   uint32_t *_SupportedByThisProvider /* [out] [ref] */,
-						   const char **_OwnerMachineName /* [out] [ref,charset(UTF16)] */);
+						   const char **_OwnerMachineName /* [out] [charset(UTF16),ref] */);
 NTSTATUS dcerpc_fss_IsPathSupported_recv(struct tevent_req *req,
 					 TALLOC_CTX *mem_ctx,
 					 uint32_t *result);
 NTSTATUS dcerpc_fss_IsPathSupported(struct dcerpc_binding_handle *h,
 				    TALLOC_CTX *mem_ctx,
-				    const char *_ShareName /* [in] [charset(UTF16),ref] */,
+				    const char *_ShareName /* [in] [ref,charset(UTF16)] */,
 				    uint8_t _magic[52] /* [in]  */,
 				    uint32_t *_SupportedByThisProvider /* [out] [ref] */,
-				    const char **_OwnerMachineName /* [out] [ref,charset(UTF16)] */,
+				    const char **_OwnerMachineName /* [out] [charset(UTF16),ref] */,
 				    uint32_t *result);
 
 struct tevent_req *dcerpc_fss_IsPathShadowCopied_r_send(TALLOC_CTX *mem_ctx,
@@ -198,7 +198,7 @@ NTSTATUS dcerpc_fss_IsPathShadowCopied_r(struct dcerpc_binding_handle *h, TALLOC
 struct tevent_req *dcerpc_fss_IsPathShadowCopied_send(TALLOC_CTX *mem_ctx,
 						      struct tevent_context *ev,
 						      struct dcerpc_binding_handle *h,
-						      const char *_ShareName /* [in] [ref,charset(UTF16)] */,
+						      const char *_ShareName /* [in] [charset(UTF16),ref] */,
 						      uint32_t *_ShadowCopyPresent /* [out] [ref] */,
 						      int32_t *_ShadowCopyCompatibility /* [out] [ref] */);
 NTSTATUS dcerpc_fss_IsPathShadowCopied_recv(struct tevent_req *req,
@@ -206,7 +206,7 @@ NTSTATUS dcerpc_fss_IsPathShadowCopied_recv(struct tevent_req *req,
 					    uint32_t *result);
 NTSTATUS dcerpc_fss_IsPathShadowCopied(struct dcerpc_binding_handle *h,
 				       TALLOC_CTX *mem_ctx,
-				       const char *_ShareName /* [in] [ref,charset(UTF16)] */,
+				       const char *_ShareName /* [in] [charset(UTF16),ref] */,
 				       uint32_t *_ShadowCopyPresent /* [out] [ref] */,
 				       int32_t *_ShadowCopyCompatibility /* [out] [ref] */,
 				       uint32_t *result);
@@ -248,7 +248,7 @@ struct tevent_req *dcerpc_fss_DeleteShareMapping_send(TALLOC_CTX *mem_ctx,
 						      struct dcerpc_binding_handle *h,
 						      struct GUID _ShadowCopySetId /* [in]  */,
 						      struct GUID _ShadowCopyId /* [in]  */,
-						      const char *_ShareName /* [in] [charset(UTF16),ref] */);
+						      const char *_ShareName /* [in] [ref,charset(UTF16)] */);
 NTSTATUS dcerpc_fss_DeleteShareMapping_recv(struct tevent_req *req,
 					    TALLOC_CTX *mem_ctx,
 					    uint32_t *result);
@@ -256,7 +256,7 @@ NTSTATUS dcerpc_fss_DeleteShareMapping(struct dcerpc_binding_handle *h,
 				       TALLOC_CTX *mem_ctx,
 				       struct GUID _ShadowCopySetId /* [in]  */,
 				       struct GUID _ShadowCopyId /* [in]  */,
-				       const char *_ShareName /* [in] [charset(UTF16),ref] */,
+				       const char *_ShareName /* [in] [ref,charset(UTF16)] */,
 				       uint32_t *result);
 
 struct tevent_req *dcerpc_fss_PrepareShadowCopySet_r_send(TALLOC_CTX *mem_ctx,
