@@ -190,7 +190,7 @@ struct tevent_req *dcerpc_samr_QueryDomainInfo_send(TALLOC_CTX *mem_ctx,
 						    struct dcerpc_binding_handle *h,
 						    struct policy_handle *_domain_handle /* [in] [ref] */,
 						    enum samr_DomainInfoClass _level /* [in]  */,
-						    union samr_DomainInfo **_info /* [out] [switch_is(level),ref] */);
+						    union samr_DomainInfo **_info /* [out] [ref,switch_is(level)] */);
 NTSTATUS dcerpc_samr_QueryDomainInfo_recv(struct tevent_req *req,
 					  TALLOC_CTX *mem_ctx,
 					  NTSTATUS *result);
@@ -198,7 +198,7 @@ NTSTATUS dcerpc_samr_QueryDomainInfo(struct dcerpc_binding_handle *h,
 				     TALLOC_CTX *mem_ctx,
 				     struct policy_handle *_domain_handle /* [in] [ref] */,
 				     enum samr_DomainInfoClass _level /* [in]  */,
-				     union samr_DomainInfo **_info /* [out] [switch_is(level),ref] */,
+				     union samr_DomainInfo **_info /* [out] [ref,switch_is(level)] */,
 				     NTSTATUS *result);
 
 struct tevent_req *dcerpc_samr_SetDomainInfo_r_send(TALLOC_CTX *mem_ctx,
@@ -212,7 +212,7 @@ struct tevent_req *dcerpc_samr_SetDomainInfo_send(TALLOC_CTX *mem_ctx,
 						  struct dcerpc_binding_handle *h,
 						  struct policy_handle *_domain_handle /* [in] [ref] */,
 						  enum samr_DomainInfoClass _level /* [in]  */,
-						  union samr_DomainInfo *_info /* [in] [ref,switch_is(level)] */);
+						  union samr_DomainInfo *_info /* [in] [switch_is(level),ref] */);
 NTSTATUS dcerpc_samr_SetDomainInfo_recv(struct tevent_req *req,
 					TALLOC_CTX *mem_ctx,
 					NTSTATUS *result);
@@ -220,7 +220,7 @@ NTSTATUS dcerpc_samr_SetDomainInfo(struct dcerpc_binding_handle *h,
 				   TALLOC_CTX *mem_ctx,
 				   struct policy_handle *_domain_handle /* [in] [ref] */,
 				   enum samr_DomainInfoClass _level /* [in]  */,
-				   union samr_DomainInfo *_info /* [in] [ref,switch_is(level)] */,
+				   union samr_DomainInfo *_info /* [in] [switch_is(level),ref] */,
 				   NTSTATUS *result);
 
 struct tevent_req *dcerpc_samr_CreateDomainGroup_r_send(TALLOC_CTX *mem_ctx,
@@ -440,7 +440,7 @@ struct tevent_req *dcerpc_samr_LookupRids_send(TALLOC_CTX *mem_ctx,
 					       struct dcerpc_binding_handle *h,
 					       struct policy_handle *_domain_handle /* [in] [ref] */,
 					       uint32_t _num_rids /* [in] [range(0,1000)] */,
-					       uint32_t *_rids /* [in] [size_is(1000),length_is(num_rids)] */,
+					       uint32_t *_rids /* [in] [length_is(num_rids),size_is(1000)] */,
 					       struct lsa_Strings *_names /* [out] [ref] */,
 					       struct samr_Ids *_types /* [out] [ref] */);
 NTSTATUS dcerpc_samr_LookupRids_recv(struct tevent_req *req,
@@ -450,7 +450,7 @@ NTSTATUS dcerpc_samr_LookupRids(struct dcerpc_binding_handle *h,
 				TALLOC_CTX *mem_ctx,
 				struct policy_handle *_domain_handle /* [in] [ref] */,
 				uint32_t _num_rids /* [in] [range(0,1000)] */,
-				uint32_t *_rids /* [in] [size_is(1000),length_is(num_rids)] */,
+				uint32_t *_rids /* [in] [length_is(num_rids),size_is(1000)] */,
 				struct lsa_Strings *_names /* [out] [ref] */,
 				struct samr_Ids *_types /* [out] [ref] */,
 				NTSTATUS *result);
@@ -512,7 +512,7 @@ struct tevent_req *dcerpc_samr_SetGroupInfo_send(TALLOC_CTX *mem_ctx,
 						 struct dcerpc_binding_handle *h,
 						 struct policy_handle *_group_handle /* [in] [ref] */,
 						 enum samr_GroupInfoEnum _level /* [in]  */,
-						 union samr_GroupInfo *_info /* [in] [switch_is(level),ref] */);
+						 union samr_GroupInfo *_info /* [in] [ref,switch_is(level)] */);
 NTSTATUS dcerpc_samr_SetGroupInfo_recv(struct tevent_req *req,
 				       TALLOC_CTX *mem_ctx,
 				       NTSTATUS *result);
@@ -520,7 +520,7 @@ NTSTATUS dcerpc_samr_SetGroupInfo(struct dcerpc_binding_handle *h,
 				  TALLOC_CTX *mem_ctx,
 				  struct policy_handle *_group_handle /* [in] [ref] */,
 				  enum samr_GroupInfoEnum _level /* [in]  */,
-				  union samr_GroupInfo *_info /* [in] [switch_is(level),ref] */,
+				  union samr_GroupInfo *_info /* [in] [ref,switch_is(level)] */,
 				  NTSTATUS *result);
 
 struct tevent_req *dcerpc_samr_AddGroupMember_r_send(TALLOC_CTX *mem_ctx,
@@ -682,7 +682,7 @@ struct tevent_req *dcerpc_samr_SetAliasInfo_send(TALLOC_CTX *mem_ctx,
 						 struct dcerpc_binding_handle *h,
 						 struct policy_handle *_alias_handle /* [in] [ref] */,
 						 enum samr_AliasInfoEnum _level /* [in]  */,
-						 union samr_AliasInfo *_info /* [in] [switch_is(level),ref] */);
+						 union samr_AliasInfo *_info /* [in] [ref,switch_is(level)] */);
 NTSTATUS dcerpc_samr_SetAliasInfo_recv(struct tevent_req *req,
 				       TALLOC_CTX *mem_ctx,
 				       NTSTATUS *result);
@@ -690,7 +690,7 @@ NTSTATUS dcerpc_samr_SetAliasInfo(struct dcerpc_binding_handle *h,
 				  TALLOC_CTX *mem_ctx,
 				  struct policy_handle *_alias_handle /* [in] [ref] */,
 				  enum samr_AliasInfoEnum _level /* [in]  */,
-				  union samr_AliasInfo *_info /* [in] [switch_is(level),ref] */,
+				  union samr_AliasInfo *_info /* [in] [ref,switch_is(level)] */,
 				  NTSTATUS *result);
 
 struct tevent_req *dcerpc_samr_DeleteDomAlias_r_send(TALLOC_CTX *mem_ctx,
@@ -846,7 +846,7 @@ struct tevent_req *dcerpc_samr_SetUserInfo_send(TALLOC_CTX *mem_ctx,
 						struct dcerpc_binding_handle *h,
 						struct policy_handle *_user_handle /* [in] [ref] */,
 						enum samr_UserInfoLevel _level /* [in]  */,
-						union samr_UserInfo *_info /* [in] [ref,switch_is(level)] */);
+						union samr_UserInfo *_info /* [in] [switch_is(level),ref] */);
 NTSTATUS dcerpc_samr_SetUserInfo_recv(struct tevent_req *req,
 				      TALLOC_CTX *mem_ctx,
 				      NTSTATUS *result);
@@ -854,7 +854,7 @@ NTSTATUS dcerpc_samr_SetUserInfo(struct dcerpc_binding_handle *h,
 				 TALLOC_CTX *mem_ctx,
 				 struct policy_handle *_user_handle /* [in] [ref] */,
 				 enum samr_UserInfoLevel _level /* [in]  */,
-				 union samr_UserInfo *_info /* [in] [ref,switch_is(level)] */,
+				 union samr_UserInfo *_info /* [in] [switch_is(level),ref] */,
 				 NTSTATUS *result);
 
 struct tevent_req *dcerpc_samr_ChangePasswordUser_r_send(TALLOC_CTX *mem_ctx,
@@ -1058,7 +1058,7 @@ struct tevent_req *dcerpc_samr_QueryDomainInfo2_send(TALLOC_CTX *mem_ctx,
 						     struct dcerpc_binding_handle *h,
 						     struct policy_handle *_domain_handle /* [in] [ref] */,
 						     enum samr_DomainInfoClass _level /* [in]  */,
-						     union samr_DomainInfo **_info /* [out] [switch_is(level),ref] */);
+						     union samr_DomainInfo **_info /* [out] [ref,switch_is(level)] */);
 NTSTATUS dcerpc_samr_QueryDomainInfo2_recv(struct tevent_req *req,
 					   TALLOC_CTX *mem_ctx,
 					   NTSTATUS *result);
@@ -1066,7 +1066,7 @@ NTSTATUS dcerpc_samr_QueryDomainInfo2(struct dcerpc_binding_handle *h,
 				      TALLOC_CTX *mem_ctx,
 				      struct policy_handle *_domain_handle /* [in] [ref] */,
 				      enum samr_DomainInfoClass _level /* [in]  */,
-				      union samr_DomainInfo **_info /* [out] [switch_is(level),ref] */,
+				      union samr_DomainInfo **_info /* [out] [ref,switch_is(level)] */,
 				      NTSTATUS *result);
 
 struct tevent_req *dcerpc_samr_QueryUserInfo2_r_send(TALLOC_CTX *mem_ctx,
@@ -1107,7 +1107,7 @@ struct tevent_req *dcerpc_samr_QueryDisplayInfo2_send(TALLOC_CTX *mem_ctx,
 						      uint32_t _buf_size /* [in]  */,
 						      uint32_t *_total_size /* [out] [ref] */,
 						      uint32_t *_returned_size /* [out] [ref] */,
-						      union samr_DispInfo *_info /* [out] [ref,switch_is(level)] */);
+						      union samr_DispInfo *_info /* [out] [switch_is(level),ref] */);
 NTSTATUS dcerpc_samr_QueryDisplayInfo2_recv(struct tevent_req *req,
 					    TALLOC_CTX *mem_ctx,
 					    NTSTATUS *result);
@@ -1120,7 +1120,7 @@ NTSTATUS dcerpc_samr_QueryDisplayInfo2(struct dcerpc_binding_handle *h,
 				       uint32_t _buf_size /* [in]  */,
 				       uint32_t *_total_size /* [out] [ref] */,
 				       uint32_t *_returned_size /* [out] [ref] */,
-				       union samr_DispInfo *_info /* [out] [ref,switch_is(level)] */,
+				       union samr_DispInfo *_info /* [out] [switch_is(level),ref] */,
 				       NTSTATUS *result);
 
 struct tevent_req *dcerpc_samr_GetDisplayEnumerationIndex2_r_send(TALLOC_CTX *mem_ctx,
@@ -1193,7 +1193,7 @@ struct tevent_req *dcerpc_samr_QueryDisplayInfo3_send(TALLOC_CTX *mem_ctx,
 						      uint32_t _buf_size /* [in]  */,
 						      uint32_t *_total_size /* [out] [ref] */,
 						      uint32_t *_returned_size /* [out] [ref] */,
-						      union samr_DispInfo *_info /* [out] [ref,switch_is(level)] */);
+						      union samr_DispInfo *_info /* [out] [switch_is(level),ref] */);
 NTSTATUS dcerpc_samr_QueryDisplayInfo3_recv(struct tevent_req *req,
 					    TALLOC_CTX *mem_ctx,
 					    NTSTATUS *result);
@@ -1206,7 +1206,7 @@ NTSTATUS dcerpc_samr_QueryDisplayInfo3(struct dcerpc_binding_handle *h,
 				       uint32_t _buf_size /* [in]  */,
 				       uint32_t *_total_size /* [out] [ref] */,
 				       uint32_t *_returned_size /* [out] [ref] */,
-				       union samr_DispInfo *_info /* [out] [ref,switch_is(level)] */,
+				       union samr_DispInfo *_info /* [out] [switch_is(level),ref] */,
 				       NTSTATUS *result);
 
 struct tevent_req *dcerpc_samr_AddMultipleMembersToAlias_r_send(TALLOC_CTX *mem_ctx,
@@ -1332,7 +1332,7 @@ NTSTATUS dcerpc_samr_Connect2_r(struct dcerpc_binding_handle *h, TALLOC_CTX *mem
 struct tevent_req *dcerpc_samr_Connect2_send(TALLOC_CTX *mem_ctx,
 					     struct tevent_context *ev,
 					     struct dcerpc_binding_handle *h,
-					     const char *_system_name /* [in] [unique,charset(UTF16)] */,
+					     const char *_system_name /* [in] [charset(UTF16),unique] */,
 					     uint32_t _access_mask /* [in]  */,
 					     struct policy_handle *_connect_handle /* [out] [ref] */);
 NTSTATUS dcerpc_samr_Connect2_recv(struct tevent_req *req,
@@ -1340,7 +1340,7 @@ NTSTATUS dcerpc_samr_Connect2_recv(struct tevent_req *req,
 				   NTSTATUS *result);
 NTSTATUS dcerpc_samr_Connect2(struct dcerpc_binding_handle *h,
 			      TALLOC_CTX *mem_ctx,
-			      const char *_system_name /* [in] [unique,charset(UTF16)] */,
+			      const char *_system_name /* [in] [charset(UTF16),unique] */,
 			      uint32_t _access_mask /* [in]  */,
 			      struct policy_handle *_connect_handle /* [out] [ref] */,
 			      NTSTATUS *result);
@@ -1420,7 +1420,7 @@ NTSTATUS dcerpc_samr_Connect3_r(struct dcerpc_binding_handle *h, TALLOC_CTX *mem
 struct tevent_req *dcerpc_samr_Connect3_send(TALLOC_CTX *mem_ctx,
 					     struct tevent_context *ev,
 					     struct dcerpc_binding_handle *h,
-					     const char *_system_name /* [in] [charset(UTF16),unique] */,
+					     const char *_system_name /* [in] [unique,charset(UTF16)] */,
 					     uint32_t _unknown /* [in]  */,
 					     uint32_t _access_mask /* [in]  */,
 					     struct policy_handle *_connect_handle /* [out] [ref] */);
@@ -1429,7 +1429,7 @@ NTSTATUS dcerpc_samr_Connect3_recv(struct tevent_req *req,
 				   NTSTATUS *result);
 NTSTATUS dcerpc_samr_Connect3(struct dcerpc_binding_handle *h,
 			      TALLOC_CTX *mem_ctx,
-			      const char *_system_name /* [in] [charset(UTF16),unique] */,
+			      const char *_system_name /* [in] [unique,charset(UTF16)] */,
 			      uint32_t _unknown /* [in]  */,
 			      uint32_t _access_mask /* [in]  */,
 			      struct policy_handle *_connect_handle /* [out] [ref] */,
@@ -1444,7 +1444,7 @@ NTSTATUS dcerpc_samr_Connect4_r(struct dcerpc_binding_handle *h, TALLOC_CTX *mem
 struct tevent_req *dcerpc_samr_Connect4_send(TALLOC_CTX *mem_ctx,
 					     struct tevent_context *ev,
 					     struct dcerpc_binding_handle *h,
-					     const char *_system_name /* [in] [charset(UTF16),unique] */,
+					     const char *_system_name /* [in] [unique,charset(UTF16)] */,
 					     enum samr_ConnectVersion _client_version /* [in]  */,
 					     uint32_t _access_mask /* [in]  */,
 					     struct policy_handle *_connect_handle /* [out] [ref] */);
@@ -1453,7 +1453,7 @@ NTSTATUS dcerpc_samr_Connect4_recv(struct tevent_req *req,
 				   NTSTATUS *result);
 NTSTATUS dcerpc_samr_Connect4(struct dcerpc_binding_handle *h,
 			      TALLOC_CTX *mem_ctx,
-			      const char *_system_name /* [in] [charset(UTF16),unique] */,
+			      const char *_system_name /* [in] [unique,charset(UTF16)] */,
 			      enum samr_ConnectVersion _client_version /* [in]  */,
 			      uint32_t _access_mask /* [in]  */,
 			      struct policy_handle *_connect_handle /* [out] [ref] */,
@@ -1509,7 +1509,7 @@ struct tevent_req *dcerpc_samr_Connect5_send(TALLOC_CTX *mem_ctx,
 					     uint32_t _level_in /* [in]  */,
 					     union samr_ConnectInfo *_info_in /* [in] [switch_is(level_in),ref] */,
 					     uint32_t *_level_out /* [out] [ref] */,
-					     union samr_ConnectInfo *_info_out /* [out] [ref,switch_is(*level_out)] */,
+					     union samr_ConnectInfo *_info_out /* [out] [switch_is(*level_out),ref] */,
 					     struct policy_handle *_connect_handle /* [out] [ref] */);
 NTSTATUS dcerpc_samr_Connect5_recv(struct tevent_req *req,
 				   TALLOC_CTX *mem_ctx,
@@ -1521,7 +1521,7 @@ NTSTATUS dcerpc_samr_Connect5(struct dcerpc_binding_handle *h,
 			      uint32_t _level_in /* [in]  */,
 			      union samr_ConnectInfo *_info_in /* [in] [switch_is(level_in),ref] */,
 			      uint32_t *_level_out /* [out] [ref] */,
-			      union samr_ConnectInfo *_info_out /* [out] [ref,switch_is(*level_out)] */,
+			      union samr_ConnectInfo *_info_out /* [out] [switch_is(*level_out),ref] */,
 			      struct policy_handle *_connect_handle /* [out] [ref] */,
 			      NTSTATUS *result);
 
@@ -1579,7 +1579,7 @@ struct tevent_req *dcerpc_samr_ValidatePassword_send(TALLOC_CTX *mem_ctx,
 						     struct tevent_context *ev,
 						     struct dcerpc_binding_handle *h,
 						     enum samr_ValidatePasswordLevel _level /* [in]  */,
-						     union samr_ValidatePasswordReq *_req /* [in] [ref,switch_is(level)] */,
+						     union samr_ValidatePasswordReq *_req /* [in] [switch_is(level),ref] */,
 						     union samr_ValidatePasswordRep **_rep /* [out] [switch_is(level),ref] */);
 NTSTATUS dcerpc_samr_ValidatePassword_recv(struct tevent_req *req,
 					   TALLOC_CTX *mem_ctx,
@@ -1587,7 +1587,7 @@ NTSTATUS dcerpc_samr_ValidatePassword_recv(struct tevent_req *req,
 NTSTATUS dcerpc_samr_ValidatePassword(struct dcerpc_binding_handle *h,
 				      TALLOC_CTX *mem_ctx,
 				      enum samr_ValidatePasswordLevel _level /* [in]  */,
-				      union samr_ValidatePasswordReq *_req /* [in] [ref,switch_is(level)] */,
+				      union samr_ValidatePasswordReq *_req /* [in] [switch_is(level),ref] */,
 				      union samr_ValidatePasswordRep **_rep /* [out] [switch_is(level),ref] */,
 				      NTSTATUS *result);
 
