@@ -14,7 +14,7 @@ NTSTATUS dcerpc_srvsvc_NetCharDevEnum_r(struct dcerpc_binding_handle *h, TALLOC_
 struct tevent_req *dcerpc_srvsvc_NetCharDevEnum_send(TALLOC_CTX *mem_ctx,
 						     struct tevent_context *ev,
 						     struct dcerpc_binding_handle *h,
-						     const char *_server_unc /* [in] [charset(UTF16),unique] */,
+						     const char *_server_unc /* [in] [unique,charset(UTF16)] */,
 						     struct srvsvc_NetCharDevInfoCtr *_info_ctr /* [in,out] [ref] */,
 						     uint32_t _max_buffer /* [in]  */,
 						     uint32_t *_totalentries /* [out] [ref] */,
@@ -24,7 +24,7 @@ NTSTATUS dcerpc_srvsvc_NetCharDevEnum_recv(struct tevent_req *req,
 					   WERROR *result);
 NTSTATUS dcerpc_srvsvc_NetCharDevEnum(struct dcerpc_binding_handle *h,
 				      TALLOC_CTX *mem_ctx,
-				      const char *_server_unc /* [in] [charset(UTF16),unique] */,
+				      const char *_server_unc /* [in] [unique,charset(UTF16)] */,
 				      struct srvsvc_NetCharDevInfoCtr *_info_ctr /* [in,out] [ref] */,
 				      uint32_t _max_buffer /* [in]  */,
 				      uint32_t *_totalentries /* [out] [ref] */,
@@ -87,7 +87,7 @@ struct tevent_req *dcerpc_srvsvc_NetCharDevQEnum_send(TALLOC_CTX *mem_ctx,
 						      struct tevent_context *ev,
 						      struct dcerpc_binding_handle *h,
 						      const char *_server_unc /* [in] [charset(UTF16),unique] */,
-						      const char *_user /* [in] [unique,charset(UTF16)] */,
+						      const char *_user /* [in] [charset(UTF16),unique] */,
 						      struct srvsvc_NetCharDevQInfoCtr *_info_ctr /* [in,out] [ref] */,
 						      uint32_t _max_buffer /* [in]  */,
 						      uint32_t *_totalentries /* [out] [ref] */,
@@ -98,7 +98,7 @@ NTSTATUS dcerpc_srvsvc_NetCharDevQEnum_recv(struct tevent_req *req,
 NTSTATUS dcerpc_srvsvc_NetCharDevQEnum(struct dcerpc_binding_handle *h,
 				       TALLOC_CTX *mem_ctx,
 				       const char *_server_unc /* [in] [charset(UTF16),unique] */,
-				       const char *_user /* [in] [unique,charset(UTF16)] */,
+				       const char *_user /* [in] [charset(UTF16),unique] */,
 				       struct srvsvc_NetCharDevQInfoCtr *_info_ctr /* [in,out] [ref] */,
 				       uint32_t _max_buffer /* [in]  */,
 				       uint32_t *_totalentries /* [out] [ref] */,
@@ -114,21 +114,21 @@ NTSTATUS dcerpc_srvsvc_NetCharDevQGetInfo_r(struct dcerpc_binding_handle *h, TAL
 struct tevent_req *dcerpc_srvsvc_NetCharDevQGetInfo_send(TALLOC_CTX *mem_ctx,
 							 struct tevent_context *ev,
 							 struct dcerpc_binding_handle *h,
-							 const char *_server_unc /* [in] [charset(UTF16),unique] */,
+							 const char *_server_unc /* [in] [unique,charset(UTF16)] */,
 							 const char *_queue_name /* [in] [charset(UTF16)] */,
 							 const char *_user /* [in] [charset(UTF16)] */,
 							 uint32_t _level /* [in]  */,
-							 union srvsvc_NetCharDevQInfo *_info /* [out] [switch_is(level),ref] */);
+							 union srvsvc_NetCharDevQInfo *_info /* [out] [ref,switch_is(level)] */);
 NTSTATUS dcerpc_srvsvc_NetCharDevQGetInfo_recv(struct tevent_req *req,
 					       TALLOC_CTX *mem_ctx,
 					       WERROR *result);
 NTSTATUS dcerpc_srvsvc_NetCharDevQGetInfo(struct dcerpc_binding_handle *h,
 					  TALLOC_CTX *mem_ctx,
-					  const char *_server_unc /* [in] [charset(UTF16),unique] */,
+					  const char *_server_unc /* [in] [unique,charset(UTF16)] */,
 					  const char *_queue_name /* [in] [charset(UTF16)] */,
 					  const char *_user /* [in] [charset(UTF16)] */,
 					  uint32_t _level /* [in]  */,
-					  union srvsvc_NetCharDevQInfo *_info /* [out] [switch_is(level),ref] */,
+					  union srvsvc_NetCharDevQInfo *_info /* [out] [ref,switch_is(level)] */,
 					  WERROR *result);
 
 struct tevent_req *dcerpc_srvsvc_NetCharDevQSetInfo_r_send(TALLOC_CTX *mem_ctx,
@@ -237,8 +237,8 @@ struct tevent_req *dcerpc_srvsvc_NetFileEnum_send(TALLOC_CTX *mem_ctx,
 						  struct tevent_context *ev,
 						  struct dcerpc_binding_handle *h,
 						  const char *_server_unc /* [in] [charset(UTF16),unique] */,
-						  const char *_path /* [in] [unique,charset(UTF16)] */,
-						  const char *_user /* [in] [charset(UTF16),unique] */,
+						  const char *_path /* [in] [charset(UTF16),unique] */,
+						  const char *_user /* [in] [unique,charset(UTF16)] */,
 						  struct srvsvc_NetFileInfoCtr *_info_ctr /* [in,out] [ref] */,
 						  uint32_t _max_buffer /* [in]  */,
 						  uint32_t *_totalentries /* [out] [ref] */,
@@ -249,8 +249,8 @@ NTSTATUS dcerpc_srvsvc_NetFileEnum_recv(struct tevent_req *req,
 NTSTATUS dcerpc_srvsvc_NetFileEnum(struct dcerpc_binding_handle *h,
 				   TALLOC_CTX *mem_ctx,
 				   const char *_server_unc /* [in] [charset(UTF16),unique] */,
-				   const char *_path /* [in] [unique,charset(UTF16)] */,
-				   const char *_user /* [in] [charset(UTF16),unique] */,
+				   const char *_path /* [in] [charset(UTF16),unique] */,
+				   const char *_user /* [in] [unique,charset(UTF16)] */,
 				   struct srvsvc_NetFileInfoCtr *_info_ctr /* [in,out] [ref] */,
 				   uint32_t _max_buffer /* [in]  */,
 				   uint32_t *_totalentries /* [out] [ref] */,
@@ -269,7 +269,7 @@ struct tevent_req *dcerpc_srvsvc_NetFileGetInfo_send(TALLOC_CTX *mem_ctx,
 						     const char *_server_unc /* [in] [unique,charset(UTF16)] */,
 						     uint32_t _fid /* [in]  */,
 						     uint32_t _level /* [in]  */,
-						     union srvsvc_NetFileInfo *_info /* [out] [switch_is(level),ref] */);
+						     union srvsvc_NetFileInfo *_info /* [out] [ref,switch_is(level)] */);
 NTSTATUS dcerpc_srvsvc_NetFileGetInfo_recv(struct tevent_req *req,
 					   TALLOC_CTX *mem_ctx,
 					   WERROR *result);
@@ -278,7 +278,7 @@ NTSTATUS dcerpc_srvsvc_NetFileGetInfo(struct dcerpc_binding_handle *h,
 				      const char *_server_unc /* [in] [unique,charset(UTF16)] */,
 				      uint32_t _fid /* [in]  */,
 				      uint32_t _level /* [in]  */,
-				      union srvsvc_NetFileInfo *_info /* [out] [switch_is(level),ref] */,
+				      union srvsvc_NetFileInfo *_info /* [out] [ref,switch_is(level)] */,
 				      WERROR *result);
 
 struct tevent_req *dcerpc_srvsvc_NetFileClose_r_send(TALLOC_CTX *mem_ctx,
@@ -310,9 +310,9 @@ NTSTATUS dcerpc_srvsvc_NetSessEnum_r(struct dcerpc_binding_handle *h, TALLOC_CTX
 struct tevent_req *dcerpc_srvsvc_NetSessEnum_send(TALLOC_CTX *mem_ctx,
 						  struct tevent_context *ev,
 						  struct dcerpc_binding_handle *h,
-						  const char *_server_unc /* [in] [unique,charset(UTF16)] */,
-						  const char *_client /* [in] [charset(UTF16),unique] */,
-						  const char *_user /* [in] [unique,charset(UTF16)] */,
+						  const char *_server_unc /* [in] [charset(UTF16),unique] */,
+						  const char *_client /* [in] [unique,charset(UTF16)] */,
+						  const char *_user /* [in] [charset(UTF16),unique] */,
 						  struct srvsvc_NetSessInfoCtr *_info_ctr /* [in,out] [ref] */,
 						  uint32_t _max_buffer /* [in]  */,
 						  uint32_t *_totalentries /* [out] [ref] */,
@@ -322,9 +322,9 @@ NTSTATUS dcerpc_srvsvc_NetSessEnum_recv(struct tevent_req *req,
 					WERROR *result);
 NTSTATUS dcerpc_srvsvc_NetSessEnum(struct dcerpc_binding_handle *h,
 				   TALLOC_CTX *mem_ctx,
-				   const char *_server_unc /* [in] [unique,charset(UTF16)] */,
-				   const char *_client /* [in] [charset(UTF16),unique] */,
-				   const char *_user /* [in] [unique,charset(UTF16)] */,
+				   const char *_server_unc /* [in] [charset(UTF16),unique] */,
+				   const char *_client /* [in] [unique,charset(UTF16)] */,
+				   const char *_user /* [in] [charset(UTF16),unique] */,
 				   struct srvsvc_NetSessInfoCtr *_info_ctr /* [in,out] [ref] */,
 				   uint32_t _max_buffer /* [in]  */,
 				   uint32_t *_totalentries /* [out] [ref] */,
@@ -340,17 +340,17 @@ NTSTATUS dcerpc_srvsvc_NetSessDel_r(struct dcerpc_binding_handle *h, TALLOC_CTX
 struct tevent_req *dcerpc_srvsvc_NetSessDel_send(TALLOC_CTX *mem_ctx,
 						 struct tevent_context *ev,
 						 struct dcerpc_binding_handle *h,
-						 const char *_server_unc /* [in] [charset(UTF16),unique] */,
+						 const char *_server_unc /* [in] [unique,charset(UTF16)] */,
 						 const char *_client /* [in] [charset(UTF16),unique] */,
-						 const char *_user /* [in] [charset(UTF16),unique] */);
+						 const char *_user /* [in] [unique,charset(UTF16)] */);
 NTSTATUS dcerpc_srvsvc_NetSessDel_recv(struct tevent_req *req,
 				       TALLOC_CTX *mem_ctx,
 				       WERROR *result);
 NTSTATUS dcerpc_srvsvc_NetSessDel(struct dcerpc_binding_handle *h,
 				  TALLOC_CTX *mem_ctx,
-				  const char *_server_unc /* [in] [charset(UTF16),unique] */,
+				  const char *_server_unc /* [in] [unique,charset(UTF16)] */,
 				  const char *_client /* [in] [charset(UTF16),unique] */,
-				  const char *_user /* [in] [charset(UTF16),unique] */,
+				  const char *_user /* [in] [unique,charset(UTF16)] */,
 				  WERROR *result);
 
 struct tevent_req *dcerpc_srvsvc_NetShareAdd_r_send(TALLOC_CTX *mem_ctx,
@@ -412,7 +412,7 @@ NTSTATUS dcerpc_srvsvc_NetShareGetInfo_r(struct dcerpc_binding_handle *h, TALLOC
 struct tevent_req *dcerpc_srvsvc_NetShareGetInfo_send(TALLOC_CTX *mem_ctx,
 						      struct tevent_context *ev,
 						      struct dcerpc_binding_handle *h,
-						      const char *_server_unc /* [in] [unique,charset(UTF16)] */,
+						      const char *_server_unc /* [in] [charset(UTF16),unique] */,
 						      const char *_share_name /* [in] [charset(UTF16)] */,
 						      uint32_t _level /* [in]  */,
 						      union srvsvc_NetShareInfo *_info /* [out] [ref,switch_is(level)] */);
@@ -421,7 +421,7 @@ NTSTATUS dcerpc_srvsvc_NetShareGetInfo_recv(struct tevent_req *req,
 					    WERROR *result);
 NTSTATUS dcerpc_srvsvc_NetShareGetInfo(struct dcerpc_binding_handle *h,
 				       TALLOC_CTX *mem_ctx,
-				       const char *_server_unc /* [in] [unique,charset(UTF16)] */,
+				       const char *_server_unc /* [in] [charset(UTF16),unique] */,
 				       const char *_share_name /* [in] [charset(UTF16)] */,
 				       uint32_t _level /* [in]  */,
 				       union srvsvc_NetShareInfo *_info /* [out] [ref,switch_is(level)] */,
@@ -484,7 +484,7 @@ NTSTATUS dcerpc_srvsvc_NetShareDelSticky_r(struct dcerpc_binding_handle *h, TALL
 struct tevent_req *dcerpc_srvsvc_NetShareDelSticky_send(TALLOC_CTX *mem_ctx,
 							struct tevent_context *ev,
 							struct dcerpc_binding_handle *h,
-							const char *_server_unc /* [in] [unique,charset(UTF16)] */,
+							const char *_server_unc /* [in] [charset(UTF16),unique] */,
 							const char *_share_name /* [in] [charset(UTF16)] */,
 							uint32_t _reserved /* [in]  */);
 NTSTATUS dcerpc_srvsvc_NetShareDelSticky_recv(struct tevent_req *req,
@@ -492,7 +492,7 @@ NTSTATUS dcerpc_srvsvc_NetShareDelSticky_recv(struct tevent_req *req,
 					      WERROR *result);
 NTSTATUS dcerpc_srvsvc_NetShareDelSticky(struct dcerpc_binding_handle *h,
 					 TALLOC_CTX *mem_ctx,
-					 const char *_server_unc /* [in] [unique,charset(UTF16)] */,
+					 const char *_server_unc /* [in] [charset(UTF16),unique] */,
 					 const char *_share_name /* [in] [charset(UTF16)] */,
 					 uint32_t _reserved /* [in]  */,
 					 WERROR *result);
@@ -528,7 +528,7 @@ NTSTATUS dcerpc_srvsvc_NetSrvGetInfo_r(struct dcerpc_binding_handle *h, TALLOC_C
 struct tevent_req *dcerpc_srvsvc_NetSrvGetInfo_send(TALLOC_CTX *mem_ctx,
 						    struct tevent_context *ev,
 						    struct dcerpc_binding_handle *h,
-						    const char *_server_unc /* [in] [charset(UTF16),unique] */,
+						    const char *_server_unc /* [in] [unique,charset(UTF16)] */,
 						    uint32_t _level /* [in]  */,
 						    union srvsvc_NetSrvInfo *_info /* [out] [switch_is(level),ref] */);
 NTSTATUS dcerpc_srvsvc_NetSrvGetInfo_recv(struct tevent_req *req,
@@ -536,7 +536,7 @@ NTSTATUS dcerpc_srvsvc_NetSrvGetInfo_recv(struct tevent_req *req,
 					  WERROR *result);
 NTSTATUS dcerpc_srvsvc_NetSrvGetInfo(struct dcerpc_binding_handle *h,
 				     TALLOC_CTX *mem_ctx,
-				     const char *_server_unc /* [in] [charset(UTF16),unique] */,
+				     const char *_server_unc /* [in] [unique,charset(UTF16)] */,
 				     uint32_t _level /* [in]  */,
 				     union srvsvc_NetSrvInfo *_info /* [out] [switch_is(level),ref] */,
 				     WERROR *result);
@@ -552,7 +552,7 @@ struct tevent_req *dcerpc_srvsvc_NetSrvSetInfo_send(TALLOC_CTX *mem_ctx,
 						    struct dcerpc_binding_handle *h,
 						    const char *_server_unc /* [in] [unique,charset(UTF16)] */,
 						    uint32_t _level /* [in]  */,
-						    union srvsvc_NetSrvInfo *_info /* [in] [ref,switch_is(level)] */,
+						    union srvsvc_NetSrvInfo *_info /* [in] [switch_is(level),ref] */,
 						    uint32_t *_parm_error /* [in,out] [unique] */);
 NTSTATUS dcerpc_srvsvc_NetSrvSetInfo_recv(struct tevent_req *req,
 					  TALLOC_CTX *mem_ctx,
@@ -561,7 +561,7 @@ NTSTATUS dcerpc_srvsvc_NetSrvSetInfo(struct dcerpc_binding_handle *h,
 				     TALLOC_CTX *mem_ctx,
 				     const char *_server_unc /* [in] [unique,charset(UTF16)] */,
 				     uint32_t _level /* [in]  */,
-				     union srvsvc_NetSrvInfo *_info /* [in] [ref,switch_is(level)] */,
+				     union srvsvc_NetSrvInfo *_info /* [in] [switch_is(level),ref] */,
 				     uint32_t *_parm_error /* [in,out] [unique] */,
 				     WERROR *result);
 
@@ -602,7 +602,7 @@ NTSTATUS dcerpc_srvsvc_NetServerStatisticsGet_r(struct dcerpc_binding_handle *h,
 struct tevent_req *dcerpc_srvsvc_NetServerStatisticsGet_send(TALLOC_CTX *mem_ctx,
 							     struct tevent_context *ev,
 							     struct dcerpc_binding_handle *h,
-							     const char *_server_unc /* [in] [unique,charset(UTF16)] */,
+							     const char *_server_unc /* [in] [charset(UTF16),unique] */,
 							     const char *_service /* [in] [unique,charset(UTF16)] */,
 							     uint32_t _level /* [in]  */,
 							     uint32_t _options /* [in]  */,
@@ -612,7 +612,7 @@ NTSTATUS dcerpc_srvsvc_NetServerStatisticsGet_recv(struct tevent_req *req,
 						   WERROR *result);
 NTSTATUS dcerpc_srvsvc_NetServerStatisticsGet(struct dcerpc_binding_handle *h,
 					      TALLOC_CTX *mem_ctx,
-					      const char *_server_unc /* [in] [unique,charset(UTF16)] */,
+					      const char *_server_unc /* [in] [charset(UTF16),unique] */,
 					      const char *_service /* [in] [unique,charset(UTF16)] */,
 					      uint32_t _level /* [in]  */,
 					      uint32_t _options /* [in]  */,
@@ -628,7 +628,7 @@ NTSTATUS dcerpc_srvsvc_NetTransportAdd_r(struct dcerpc_binding_handle *h, TALLOC
 struct tevent_req *dcerpc_srvsvc_NetTransportAdd_send(TALLOC_CTX *mem_ctx,
 						      struct tevent_context *ev,
 						      struct dcerpc_binding_handle *h,
-						      const char *_server_unc /* [in] [charset(UTF16),unique] */,
+						      const char *_server_unc /* [in] [unique,charset(UTF16)] */,
 						      uint32_t _level /* [in]  */,
 						      union srvsvc_NetTransportInfo _info /* [in] [switch_is(level)] */);
 NTSTATUS dcerpc_srvsvc_NetTransportAdd_recv(struct tevent_req *req,
@@ -636,7 +636,7 @@ NTSTATUS dcerpc_srvsvc_NetTransportAdd_recv(struct tevent_req *req,
 					    WERROR *result);
 NTSTATUS dcerpc_srvsvc_NetTransportAdd(struct dcerpc_binding_handle *h,
 				       TALLOC_CTX *mem_ctx,
-				       const char *_server_unc /* [in] [charset(UTF16),unique] */,
+				       const char *_server_unc /* [in] [unique,charset(UTF16)] */,
 				       uint32_t _level /* [in]  */,
 				       union srvsvc_NetTransportInfo _info /* [in] [switch_is(level)] */,
 				       WERROR *result);
@@ -650,7 +650,7 @@ NTSTATUS dcerpc_srvsvc_NetTransportEnum_r(struct dcerpc_binding_handle *h, TALLO
 struct tevent_req *dcerpc_srvsvc_NetTransportEnum_send(TALLOC_CTX *mem_ctx,
 						       struct tevent_context *ev,
 						       struct dcerpc_binding_handle *h,
-						       const char *_server_unc /* [in] [unique,charset(UTF16)] */,
+						       const char *_server_unc /* [in] [charset(UTF16),unique] */,
 						       struct srvsvc_NetTransportInfoCtr *_transports /* [in,out] [ref] */,
 						       uint32_t _max_buffer /* [in]  */,
 						       uint32_t *_totalentries /* [out] [ref] */,
@@ -660,7 +660,7 @@ NTSTATUS dcerpc_srvsvc_NetTransportEnum_recv(struct tevent_req *req,
 					     WERROR *result);
 NTSTATUS dcerpc_srvsvc_NetTransportEnum(struct dcerpc_binding_handle *h,
 					TALLOC_CTX *mem_ctx,
-					const char *_server_unc /* [in] [unique,charset(UTF16)] */,
+					const char *_server_unc /* [in] [charset(UTF16),unique] */,
 					struct srvsvc_NetTransportInfoCtr *_transports /* [in,out] [ref] */,
 					uint32_t _max_buffer /* [in]  */,
 					uint32_t *_totalentries /* [out] [ref] */,
@@ -698,14 +698,14 @@ NTSTATUS dcerpc_srvsvc_NetRemoteTOD_r(struct dcerpc_binding_handle *h, TALLOC_CT
 struct tevent_req *dcerpc_srvsvc_NetRemoteTOD_send(TALLOC_CTX *mem_ctx,
 						   struct tevent_context *ev,
 						   struct dcerpc_binding_handle *h,
-						   const char *_server_unc /* [in] [unique,charset(UTF16)] */,
+						   const char *_server_unc /* [in] [charset(UTF16),unique] */,
 						   struct srvsvc_NetRemoteTODInfo **_info /* [out] [ref] */);
 NTSTATUS dcerpc_srvsvc_NetRemoteTOD_recv(struct tevent_req *req,
 					 TALLOC_CTX *mem_ctx,
 					 WERROR *result);
 NTSTATUS dcerpc_srvsvc_NetRemoteTOD(struct dcerpc_binding_handle *h,
 				    TALLOC_CTX *mem_ctx,
-				    const char *_server_unc /* [in] [unique,charset(UTF16)] */,
+				    const char *_server_unc /* [in] [charset(UTF16),unique] */,
 				    struct srvsvc_NetRemoteTODInfo **_info /* [out] [ref] */,
 				    WERROR *result);
 
@@ -719,7 +719,7 @@ struct tevent_req *dcerpc_srvsvc_NetSetServiceBits_send(TALLOC_CTX *mem_ctx,
 							struct tevent_context *ev,
 							struct dcerpc_binding_handle *h,
 							const char *_server_unc /* [in] [charset(UTF16),unique] */,
-							const char *_transport /* [in] [unique,charset(UTF16)] */,
+							const char *_transport /* [in] [charset(UTF16),unique] */,
 							uint32_t _servicebits /* [in]  */,
 							uint32_t _updateimmediately /* [in]  */);
 NTSTATUS dcerpc_srvsvc_NetSetServiceBits_recv(struct tevent_req *req,
@@ -728,7 +728,7 @@ NTSTATUS dcerpc_srvsvc_NetSetServiceBits_recv(struct tevent_req *req,
 NTSTATUS dcerpc_srvsvc_NetSetServiceBits(struct dcerpc_binding_handle *h,
 					 TALLOC_CTX *mem_ctx,
 					 const char *_server_unc /* [in] [charset(UTF16),unique] */,
-					 const char *_transport /* [in] [unique,charset(UTF16)] */,
+					 const char *_transport /* [in] [charset(UTF16),unique] */,
 					 uint32_t _servicebits /* [in]  */,
 					 uint32_t _updateimmediately /* [in]  */,
 					 WERROR *result);
@@ -766,7 +766,7 @@ NTSTATUS dcerpc_srvsvc_NetPathCanonicalize_r(struct dcerpc_binding_handle *h, TA
 struct tevent_req *dcerpc_srvsvc_NetPathCanonicalize_send(TALLOC_CTX *mem_ctx,
 							  struct tevent_context *ev,
 							  struct dcerpc_binding_handle *h,
-							  const char *_server_unc /* [in] [unique,charset(UTF16)] */,
+							  const char *_server_unc /* [in] [charset(UTF16),unique] */,
 							  const char *_path /* [in] [charset(UTF16)] */,
 							  uint8_t *_can_path /* [out] [size_is(maxbuf)] */,
 							  uint32_t _maxbuf /* [in]  */,
@@ -778,7 +778,7 @@ NTSTATUS dcerpc_srvsvc_NetPathCanonicalize_recv(struct tevent_req *req,
 						WERROR *result);
 NTSTATUS dcerpc_srvsvc_NetPathCanonicalize(struct dcerpc_binding_handle *h,
 					   TALLOC_CTX *mem_ctx,
-					   const char *_server_unc /* [in] [unique,charset(UTF16)] */,
+					   const char *_server_unc /* [in] [charset(UTF16),unique] */,
 					   const char *_path /* [in] [charset(UTF16)] */,
 					   uint8_t *_can_path /* [out] [size_is(maxbuf)] */,
 					   uint32_t _maxbuf /* [in]  */,
@@ -796,7 +796,7 @@ NTSTATUS dcerpc_srvsvc_NetPathCompare_r(struct dcerpc_binding_handle *h, TALLOC_
 struct tevent_req *dcerpc_srvsvc_NetPathCompare_send(TALLOC_CTX *mem_ctx,
 						     struct tevent_context *ev,
 						     struct dcerpc_binding_handle *h,
-						     const char *_server_unc /* [in] [unique,charset(UTF16)] */,
+						     const char *_server_unc /* [in] [charset(UTF16),unique] */,
 						     const char *_path1 /* [in] [charset(UTF16)] */,
 						     const char *_path2 /* [in] [charset(UTF16)] */,
 						     uint32_t _pathtype /* [in]  */,
@@ -806,7 +806,7 @@ NTSTATUS dcerpc_srvsvc_NetPathCompare_recv(struct tevent_req *req,
 					   WERROR *result);
 NTSTATUS dcerpc_srvsvc_NetPathCompare(struct dcerpc_binding_handle *h,
 				      TALLOC_CTX *mem_ctx,
-				      const char *_server_unc /* [in] [unique,charset(UTF16)] */,
+				      const char *_server_unc /* [in] [charset(UTF16),unique] */,
 				      const char *_path1 /* [in] [charset(UTF16)] */,
 				      const char *_path2 /* [in] [charset(UTF16)] */,
 				      uint32_t _pathtype /* [in]  */,
@@ -822,7 +822,7 @@ NTSTATUS dcerpc_srvsvc_NetNameValidate_r(struct dcerpc_binding_handle *h, TALLOC
 struct tevent_req *dcerpc_srvsvc_NetNameValidate_send(TALLOC_CTX *mem_ctx,
 						      struct tevent_context *ev,
 						      struct dcerpc_binding_handle *h,
-						      const char *_server_unc /* [in] [charset(UTF16),unique] */,
+						      const char *_server_unc /* [in] [unique,charset(UTF16)] */,
 						      const char *_name /* [in] [charset(UTF16)] */,
 						      uint32_t _name_type /* [in]  */,
 						      uint32_t _flags /* [in]  */);
@@ -831,7 +831,7 @@ NTSTATUS dcerpc_srvsvc_NetNameValidate_recv(struct tevent_req *req,
 					    WERROR *result);
 NTSTATUS dcerpc_srvsvc_NetNameValidate(struct dcerpc_binding_handle *h,
 				       TALLOC_CTX *mem_ctx,
-				       const char *_server_unc /* [in] [charset(UTF16),unique] */,
+				       const char *_server_unc /* [in] [unique,charset(UTF16)] */,
 				       const char *_name /* [in] [charset(UTF16)] */,
 				       uint32_t _name_type /* [in]  */,
 				       uint32_t _flags /* [in]  */,
@@ -846,7 +846,7 @@ NTSTATUS dcerpc_srvsvc_NetPRNameCompare_r(struct dcerpc_binding_handle *h, TALLO
 struct tevent_req *dcerpc_srvsvc_NetPRNameCompare_send(TALLOC_CTX *mem_ctx,
 						       struct tevent_context *ev,
 						       struct dcerpc_binding_handle *h,
-						       const char *_server_unc /* [in] [charset(UTF16),unique] */,
+						       const char *_server_unc /* [in] [unique,charset(UTF16)] */,
 						       const char *_name1 /* [in] [charset(UTF16)] */,
 						       const char *_name2 /* [in] [charset(UTF16)] */,
 						       uint32_t _name_type /* [in]  */,
@@ -856,7 +856,7 @@ NTSTATUS dcerpc_srvsvc_NetPRNameCompare_recv(struct tevent_req *req,
 					     WERROR *result);
 NTSTATUS dcerpc_srvsvc_NetPRNameCompare(struct dcerpc_binding_handle *h,
 					TALLOC_CTX *mem_ctx,
-					const char *_server_unc /* [in] [charset(UTF16),unique] */,
+					const char *_server_unc /* [in] [unique,charset(UTF16)] */,
 					const char *_name1 /* [in] [charset(UTF16)] */,
 					const char *_name2 /* [in] [charset(UTF16)] */,
 					uint32_t _name_type /* [in]  */,
@@ -898,7 +898,7 @@ NTSTATUS dcerpc_srvsvc_NetShareDelStart_r(struct dcerpc_binding_handle *h, TALLO
 struct tevent_req *dcerpc_srvsvc_NetShareDelStart_send(TALLOC_CTX *mem_ctx,
 						       struct tevent_context *ev,
 						       struct dcerpc_binding_handle *h,
-						       const char *_server_unc /* [in] [unique,charset(UTF16)] */,
+						       const char *_server_unc /* [in] [charset(UTF16),unique] */,
 						       const char *_share /* [in] [charset(UTF16)] */,
 						       uint32_t _reserved /* [in]  */,
 						       struct policy_handle *_hnd /* [out] [unique] */);
@@ -907,7 +907,7 @@ NTSTATUS dcerpc_srvsvc_NetShareDelStart_recv(struct tevent_req *req,
 					     WERROR *result);
 NTSTATUS dcerpc_srvsvc_NetShareDelStart(struct dcerpc_binding_handle *h,
 					TALLOC_CTX *mem_ctx,
-					const char *_server_unc /* [in] [unique,charset(UTF16)] */,
+					const char *_server_unc /* [in] [charset(UTF16),unique] */,
 					const char *_share /* [in] [charset(UTF16)] */,
 					uint32_t _reserved /* [in]  */,
 					struct policy_handle *_hnd /* [out] [unique] */,
@@ -941,7 +941,7 @@ struct tevent_req *dcerpc_srvsvc_NetGetFileSecurity_send(TALLOC_CTX *mem_ctx,
 							 struct tevent_context *ev,
 							 struct dcerpc_binding_handle *h,
 							 const char *_server_unc /* [in] [unique,charset(UTF16)] */,
-							 const char *_share /* [in] [charset(UTF16),unique] */,
+							 const char *_share /* [in] [unique,charset(UTF16)] */,
 							 const char *_file /* [in] [charset(UTF16)] */,
 							 uint32_t _securityinformation /* [in]  */,
 							 struct sec_desc_buf **_sd_buf /* [out] [ref] */);
@@ -951,7 +951,7 @@ NTSTATUS dcerpc_srvsvc_NetGetFileSecurity_recv(struct tevent_req *req,
 NTSTATUS dcerpc_srvsvc_NetGetFileSecurity(struct dcerpc_binding_handle *h,
 					  TALLOC_CTX *mem_ctx,
 					  const char *_server_unc /* [in] [unique,charset(UTF16)] */,
-					  const char *_share /* [in] [charset(UTF16),unique] */,
+					  const char *_share /* [in] [unique,charset(UTF16)] */,
 					  const char *_file /* [in] [charset(UTF16)] */,
 					  uint32_t _securityinformation /* [in]  */,
 					  struct sec_desc_buf **_sd_buf /* [out] [ref] */,
@@ -966,7 +966,7 @@ NTSTATUS dcerpc_srvsvc_NetSetFileSecurity_r(struct dcerpc_binding_handle *h, TAL
 struct tevent_req *dcerpc_srvsvc_NetSetFileSecurity_send(TALLOC_CTX *mem_ctx,
 							 struct tevent_context *ev,
 							 struct dcerpc_binding_handle *h,
-							 const char *_server_unc /* [in] [unique,charset(UTF16)] */,
+							 const char *_server_unc /* [in] [charset(UTF16),unique] */,
 							 const char *_share /* [in] [charset(UTF16),unique] */,
 							 const char *_file /* [in] [charset(UTF16)] */,
 							 uint32_t _securityinformation /* [in]  */,
@@ -976,7 +976,7 @@ NTSTATUS dcerpc_srvsvc_NetSetFileSecurity_recv(struct tevent_req *req,
 					       WERROR *result);
 NTSTATUS dcerpc_srvsvc_NetSetFileSecurity(struct dcerpc_binding_handle *h,
 					  TALLOC_CTX *mem_ctx,
-					  const char *_server_unc /* [in] [unique,charset(UTF16)] */,
+					  const char *_server_unc /* [in] [charset(UTF16),unique] */,
 					  const char *_share /* [in] [charset(UTF16),unique] */,
 					  const char *_file /* [in] [charset(UTF16)] */,
 					  uint32_t _securityinformation /* [in]  */,
@@ -992,7 +992,7 @@ NTSTATUS dcerpc_srvsvc_NetServerTransportAddEx_r(struct dcerpc_binding_handle *h
 struct tevent_req *dcerpc_srvsvc_NetServerTransportAddEx_send(TALLOC_CTX *mem_ctx,
 							      struct tevent_context *ev,
 							      struct dcerpc_binding_handle *h,
-							      const char *_server_unc /* [in] [charset(UTF16),unique] */,
+							      const char *_server_unc /* [in] [unique,charset(UTF16)] */,
 							      uint32_t _level /* [in]  */,
 							      union srvsvc_NetTransportInfo _info /* [in] [switch_is(level)] */);
 NTSTATUS dcerpc_srvsvc_NetServerTransportAddEx_recv(struct tevent_req *req,
@@ -1000,7 +1000,7 @@ NTSTATUS dcerpc_srvsvc_NetServerTransportAddEx_recv(struct tevent_req *req,
 						    WERROR *result);
 NTSTATUS dcerpc_srvsvc_NetServerTransportAddEx(struct dcerpc_binding_handle *h,
 					       TALLOC_CTX *mem_ctx,
-					       const char *_server_unc /* [in] [charset(UTF16),unique] */,
+					       const char *_server_unc /* [in] [unique,charset(UTF16)] */,
 					       uint32_t _level /* [in]  */,
 					       union srvsvc_NetTransportInfo _info /* [in] [switch_is(level)] */,
 					       WERROR *result);
