@@ -78,7 +78,7 @@ NTSTATUS dcerpc_wbint_LookupName_r(struct dcerpc_binding_handle *h, TALLOC_CTX *
 struct tevent_req *dcerpc_wbint_LookupName_send(TALLOC_CTX *mem_ctx,
 						struct tevent_context *ev,
 						struct dcerpc_binding_handle *h,
-						const char *_domain /* [in] [charset(UTF8),ref] */,
+						const char *_domain /* [in] [ref,charset(UTF8)] */,
 						const char *_name /* [in] [ref,charset(UTF8)] */,
 						uint32_t _flags /* [in]  */,
 						enum lsa_SidType *_type /* [out] [ref] */,
@@ -88,7 +88,7 @@ NTSTATUS dcerpc_wbint_LookupName_recv(struct tevent_req *req,
 				      NTSTATUS *result);
 NTSTATUS dcerpc_wbint_LookupName(struct dcerpc_binding_handle *h,
 				 TALLOC_CTX *mem_ctx,
-				 const char *_domain /* [in] [charset(UTF8),ref] */,
+				 const char *_domain /* [in] [ref,charset(UTF8)] */,
 				 const char *_name /* [in] [ref,charset(UTF8)] */,
 				 uint32_t _flags /* [in]  */,
 				 enum lsa_SidType *_type /* [out] [ref] */,
@@ -124,7 +124,7 @@ NTSTATUS dcerpc_wbint_Uid2Sid_r(struct dcerpc_binding_handle *h, TALLOC_CTX *mem
 struct tevent_req *dcerpc_wbint_Uid2Sid_send(TALLOC_CTX *mem_ctx,
 					     struct tevent_context *ev,
 					     struct dcerpc_binding_handle *h,
-					     const char *_dom_name /* [in] [charset(UTF8),unique] */,
+					     const char *_dom_name /* [in] [unique,charset(UTF8)] */,
 					     uint64_t _uid /* [in]  */,
 					     struct dom_sid *_sid /* [out] [ref] */);
 NTSTATUS dcerpc_wbint_Uid2Sid_recv(struct tevent_req *req,
@@ -132,7 +132,7 @@ NTSTATUS dcerpc_wbint_Uid2Sid_recv(struct tevent_req *req,
 				   NTSTATUS *result);
 NTSTATUS dcerpc_wbint_Uid2Sid(struct dcerpc_binding_handle *h,
 			      TALLOC_CTX *mem_ctx,
-			      const char *_dom_name /* [in] [charset(UTF8),unique] */,
+			      const char *_dom_name /* [in] [unique,charset(UTF8)] */,
 			      uint64_t _uid /* [in]  */,
 			      struct dom_sid *_sid /* [out] [ref] */,
 			      NTSTATUS *result);
@@ -342,7 +342,7 @@ struct tevent_req *dcerpc_wbint_DsGetDcName_send(TALLOC_CTX *mem_ctx,
 						 struct dcerpc_binding_handle *h,
 						 const char *_domain_name /* [in] [ref,charset(UTF8)] */,
 						 struct GUID *_domain_guid /* [in] [unique] */,
-						 const char *_site_name /* [in] [unique,charset(UTF8)] */,
+						 const char *_site_name /* [in] [charset(UTF8),unique] */,
 						 uint32_t _flags /* [in]  */,
 						 struct netr_DsRGetDCNameInfo **_dc_info /* [out] [ref] */);
 NTSTATUS dcerpc_wbint_DsGetDcName_recv(struct tevent_req *req,
@@ -352,7 +352,7 @@ NTSTATUS dcerpc_wbint_DsGetDcName(struct dcerpc_binding_handle *h,
 				  TALLOC_CTX *mem_ctx,
 				  const char *_domain_name /* [in] [ref,charset(UTF8)] */,
 				  struct GUID *_domain_guid /* [in] [unique] */,
-				  const char *_site_name /* [in] [unique,charset(UTF8)] */,
+				  const char *_site_name /* [in] [charset(UTF8),unique] */,
 				  uint32_t _flags /* [in]  */,
 				  struct netr_DsRGetDCNameInfo **_dc_info /* [out] [ref] */,
 				  NTSTATUS *result);
