@@ -36,18 +36,18 @@ NTSTATUS dcerpc_wkssvc_NetWkstaSetInfo_r(struct dcerpc_binding_handle *h, TALLOC
 struct tevent_req *dcerpc_wkssvc_NetWkstaSetInfo_send(TALLOC_CTX *mem_ctx,
 						      struct tevent_context *ev,
 						      struct dcerpc_binding_handle *h,
-						      const char *_server_name /* [in] [charset(UTF16),unique] */,
+						      const char *_server_name /* [in] [unique,charset(UTF16)] */,
 						      uint32_t _level /* [in]  */,
-						      union wkssvc_NetWkstaInfo *_info /* [in] [switch_is(level),ref] */,
+						      union wkssvc_NetWkstaInfo *_info /* [in] [ref,switch_is(level)] */,
 						      uint32_t *_parm_error /* [in,out] [ref] */);
 NTSTATUS dcerpc_wkssvc_NetWkstaSetInfo_recv(struct tevent_req *req,
 					    TALLOC_CTX *mem_ctx,
 					    WERROR *result);
 NTSTATUS dcerpc_wkssvc_NetWkstaSetInfo(struct dcerpc_binding_handle *h,
 				       TALLOC_CTX *mem_ctx,
-				       const char *_server_name /* [in] [charset(UTF16),unique] */,
+				       const char *_server_name /* [in] [unique,charset(UTF16)] */,
 				       uint32_t _level /* [in]  */,
-				       union wkssvc_NetWkstaInfo *_info /* [in] [switch_is(level),ref] */,
+				       union wkssvc_NetWkstaInfo *_info /* [in] [ref,switch_is(level)] */,
 				       uint32_t *_parm_error /* [in,out] [ref] */,
 				       WERROR *result);
 
@@ -88,7 +88,7 @@ struct tevent_req *dcerpc_wkssvc_NetrWkstaUserGetInfo_send(TALLOC_CTX *mem_ctx,
 							   struct dcerpc_binding_handle *h,
 							   const char *_unknown /* [in] [unique,charset(UTF16)] */,
 							   uint32_t _level /* [in]  */,
-							   union wkssvc_NetrWkstaUserInfo *_info /* [out] [switch_is(level),ref] */);
+							   union wkssvc_NetrWkstaUserInfo *_info /* [out] [ref,switch_is(level)] */);
 NTSTATUS dcerpc_wkssvc_NetrWkstaUserGetInfo_recv(struct tevent_req *req,
 						 TALLOC_CTX *mem_ctx,
 						 WERROR *result);
@@ -96,7 +96,7 @@ NTSTATUS dcerpc_wkssvc_NetrWkstaUserGetInfo(struct dcerpc_binding_handle *h,
 					    TALLOC_CTX *mem_ctx,
 					    const char *_unknown /* [in] [unique,charset(UTF16)] */,
 					    uint32_t _level /* [in]  */,
-					    union wkssvc_NetrWkstaUserInfo *_info /* [out] [switch_is(level),ref] */,
+					    union wkssvc_NetrWkstaUserInfo *_info /* [out] [ref,switch_is(level)] */,
 					    WERROR *result);
 
 struct tevent_req *dcerpc_wkssvc_NetrWkstaUserSetInfo_r_send(TALLOC_CTX *mem_ctx,
@@ -108,18 +108,18 @@ NTSTATUS dcerpc_wkssvc_NetrWkstaUserSetInfo_r(struct dcerpc_binding_handle *h, T
 struct tevent_req *dcerpc_wkssvc_NetrWkstaUserSetInfo_send(TALLOC_CTX *mem_ctx,
 							   struct tevent_context *ev,
 							   struct dcerpc_binding_handle *h,
-							   const char *_unknown /* [in] [unique,charset(UTF16)] */,
+							   const char *_unknown /* [in] [charset(UTF16),unique] */,
 							   uint32_t _level /* [in]  */,
-							   union wkssvc_NetrWkstaUserInfo *_info /* [in] [ref,switch_is(level)] */,
+							   union wkssvc_NetrWkstaUserInfo *_info /* [in] [switch_is(level),ref] */,
 							   uint32_t *_parm_err /* [in,out] [unique] */);
 NTSTATUS dcerpc_wkssvc_NetrWkstaUserSetInfo_recv(struct tevent_req *req,
 						 TALLOC_CTX *mem_ctx,
 						 WERROR *result);
 NTSTATUS dcerpc_wkssvc_NetrWkstaUserSetInfo(struct dcerpc_binding_handle *h,
 					    TALLOC_CTX *mem_ctx,
-					    const char *_unknown /* [in] [unique,charset(UTF16)] */,
+					    const char *_unknown /* [in] [charset(UTF16),unique] */,
 					    uint32_t _level /* [in]  */,
-					    union wkssvc_NetrWkstaUserInfo *_info /* [in] [ref,switch_is(level)] */,
+					    union wkssvc_NetrWkstaUserInfo *_info /* [in] [switch_is(level),ref] */,
 					    uint32_t *_parm_err /* [in,out] [unique] */,
 					    WERROR *result);
 
@@ -158,7 +158,7 @@ NTSTATUS dcerpc_wkssvc_NetrWkstaTransportAdd_r(struct dcerpc_binding_handle *h,
 struct tevent_req *dcerpc_wkssvc_NetrWkstaTransportAdd_send(TALLOC_CTX *mem_ctx,
 							    struct tevent_context *ev,
 							    struct dcerpc_binding_handle *h,
-							    const char *_server_name /* [in] [charset(UTF16),unique] */,
+							    const char *_server_name /* [in] [unique,charset(UTF16)] */,
 							    uint32_t _level /* [in]  */,
 							    struct wkssvc_NetWkstaTransportInfo0 *_info0 /* [in] [ref] */,
 							    uint32_t *_parm_err /* [in,out] [unique] */);
@@ -167,7 +167,7 @@ NTSTATUS dcerpc_wkssvc_NetrWkstaTransportAdd_recv(struct tevent_req *req,
 						  WERROR *result);
 NTSTATUS dcerpc_wkssvc_NetrWkstaTransportAdd(struct dcerpc_binding_handle *h,
 					     TALLOC_CTX *mem_ctx,
-					     const char *_server_name /* [in] [charset(UTF16),unique] */,
+					     const char *_server_name /* [in] [unique,charset(UTF16)] */,
 					     uint32_t _level /* [in]  */,
 					     struct wkssvc_NetWkstaTransportInfo0 *_info0 /* [in] [ref] */,
 					     uint32_t *_parm_err /* [in,out] [unique] */,
@@ -182,7 +182,7 @@ NTSTATUS dcerpc_wkssvc_NetrWkstaTransportDel_r(struct dcerpc_binding_handle *h,
 struct tevent_req *dcerpc_wkssvc_NetrWkstaTransportDel_send(TALLOC_CTX *mem_ctx,
 							    struct tevent_context *ev,
 							    struct dcerpc_binding_handle *h,
-							    const char *_server_name /* [in] [charset(UTF16),unique] */,
+							    const char *_server_name /* [in] [unique,charset(UTF16)] */,
 							    const char *_transport_name /* [in] [charset(UTF16),unique] */,
 							    uint32_t _unknown3 /* [in]  */);
 NTSTATUS dcerpc_wkssvc_NetrWkstaTransportDel_recv(struct tevent_req *req,
@@ -190,7 +190,7 @@ NTSTATUS dcerpc_wkssvc_NetrWkstaTransportDel_recv(struct tevent_req *req,
 						  WERROR *result);
 NTSTATUS dcerpc_wkssvc_NetrWkstaTransportDel(struct dcerpc_binding_handle *h,
 					     TALLOC_CTX *mem_ctx,
-					     const char *_server_name /* [in] [charset(UTF16),unique] */,
+					     const char *_server_name /* [in] [unique,charset(UTF16)] */,
 					     const char *_transport_name /* [in] [charset(UTF16),unique] */,
 					     uint32_t _unknown3 /* [in]  */,
 					     WERROR *result);
@@ -206,7 +206,7 @@ struct tevent_req *dcerpc_wkssvc_NetrUseAdd_send(TALLOC_CTX *mem_ctx,
 						 struct dcerpc_binding_handle *h,
 						 const char *_server_name /* [in] [charset(UTF16),unique] */,
 						 uint32_t _level /* [in]  */,
-						 union wkssvc_NetrUseGetInfoCtr *_ctr /* [in] [ref,switch_is(level)] */,
+						 union wkssvc_NetrUseGetInfoCtr *_ctr /* [in] [switch_is(level),ref] */,
 						 uint32_t *_parm_err /* [in,out] [unique] */);
 NTSTATUS dcerpc_wkssvc_NetrUseAdd_recv(struct tevent_req *req,
 				       TALLOC_CTX *mem_ctx,
@@ -215,7 +215,7 @@ NTSTATUS dcerpc_wkssvc_NetrUseAdd(struct dcerpc_binding_handle *h,
 				  TALLOC_CTX *mem_ctx,
 				  const char *_server_name /* [in] [charset(UTF16),unique] */,
 				  uint32_t _level /* [in]  */,
-				  union wkssvc_NetrUseGetInfoCtr *_ctr /* [in] [ref,switch_is(level)] */,
+				  union wkssvc_NetrUseGetInfoCtr *_ctr /* [in] [switch_is(level),ref] */,
 				  uint32_t *_parm_err /* [in,out] [unique] */,
 				  WERROR *result);
 
@@ -229,7 +229,7 @@ struct tevent_req *dcerpc_wkssvc_NetrUseGetInfo_send(TALLOC_CTX *mem_ctx,
 						     struct tevent_context *ev,
 						     struct dcerpc_binding_handle *h,
 						     const char *_server_name /* [in] [charset(UTF16),unique] */,
-						     const char *_use_name /* [in] [ref,charset(UTF16)] */,
+						     const char *_use_name /* [in] [charset(UTF16),ref] */,
 						     uint32_t _level /* [in]  */,
 						     union wkssvc_NetrUseGetInfoCtr *_ctr /* [out] [ref,switch_is(level)] */);
 NTSTATUS dcerpc_wkssvc_NetrUseGetInfo_recv(struct tevent_req *req,
@@ -238,7 +238,7 @@ NTSTATUS dcerpc_wkssvc_NetrUseGetInfo_recv(struct tevent_req *req,
 NTSTATUS dcerpc_wkssvc_NetrUseGetInfo(struct dcerpc_binding_handle *h,
 				      TALLOC_CTX *mem_ctx,
 				      const char *_server_name /* [in] [charset(UTF16),unique] */,
-				      const char *_use_name /* [in] [ref,charset(UTF16)] */,
+				      const char *_use_name /* [in] [charset(UTF16),ref] */,
 				      uint32_t _level /* [in]  */,
 				      union wkssvc_NetrUseGetInfoCtr *_ctr /* [out] [ref,switch_is(level)] */,
 				      WERROR *result);
@@ -253,7 +253,7 @@ struct tevent_req *dcerpc_wkssvc_NetrUseDel_send(TALLOC_CTX *mem_ctx,
 						 struct tevent_context *ev,
 						 struct dcerpc_binding_handle *h,
 						 const char *_server_name /* [in] [charset(UTF16),unique] */,
-						 const char *_use_name /* [in] [ref,charset(UTF16)] */,
+						 const char *_use_name /* [in] [charset(UTF16),ref] */,
 						 uint32_t _force_cond /* [in]  */);
 NTSTATUS dcerpc_wkssvc_NetrUseDel_recv(struct tevent_req *req,
 				       TALLOC_CTX *mem_ctx,
@@ -261,7 +261,7 @@ NTSTATUS dcerpc_wkssvc_NetrUseDel_recv(struct tevent_req *req,
 NTSTATUS dcerpc_wkssvc_NetrUseDel(struct dcerpc_binding_handle *h,
 				  TALLOC_CTX *mem_ctx,
 				  const char *_server_name /* [in] [charset(UTF16),unique] */,
-				  const char *_use_name /* [in] [ref,charset(UTF16)] */,
+				  const char *_use_name /* [in] [charset(UTF16),ref] */,
 				  uint32_t _force_cond /* [in]  */,
 				  WERROR *result);
 
@@ -300,20 +300,20 @@ NTSTATUS dcerpc_wkssvc_NetrMessageBufferSend_r(struct dcerpc_binding_handle *h,
 struct tevent_req *dcerpc_wkssvc_NetrMessageBufferSend_send(TALLOC_CTX *mem_ctx,
 							    struct tevent_context *ev,
 							    struct dcerpc_binding_handle *h,
-							    const char *_server_name /* [in] [charset(UTF16),unique] */,
-							    const char *_message_name /* [in] [ref,charset(UTF16)] */,
-							    const char *_message_sender_name /* [in] [charset(UTF16),unique] */,
-							    uint8_t *_message_buffer /* [in] [size_is(message_size),ref] */,
+							    const char *_server_name /* [in] [unique,charset(UTF16)] */,
+							    const char *_message_name /* [in] [charset(UTF16),ref] */,
+							    const char *_message_sender_name /* [in] [unique,charset(UTF16)] */,
+							    uint8_t *_message_buffer /* [in] [ref,size_is(message_size)] */,
 							    uint32_t _message_size /* [in]  */);
 NTSTATUS dcerpc_wkssvc_NetrMessageBufferSend_recv(struct tevent_req *req,
 						  TALLOC_CTX *mem_ctx,
 						  WERROR *result);
 NTSTATUS dcerpc_wkssvc_NetrMessageBufferSend(struct dcerpc_binding_handle *h,
 					     TALLOC_CTX *mem_ctx,
-					     const char *_server_name /* [in] [charset(UTF16),unique] */,
-					     const char *_message_name /* [in] [ref,charset(UTF16)] */,
-					     const char *_message_sender_name /* [in] [charset(UTF16),unique] */,
-					     uint8_t *_message_buffer /* [in] [size_is(message_size),ref] */,
+					     const char *_server_name /* [in] [unique,charset(UTF16)] */,
+					     const char *_message_name /* [in] [charset(UTF16),ref] */,
+					     const char *_message_sender_name /* [in] [unique,charset(UTF16)] */,
+					     uint8_t *_message_buffer /* [in] [ref,size_is(message_size)] */,
 					     uint32_t _message_size /* [in]  */,
 					     WERROR *result);
 
@@ -326,7 +326,7 @@ NTSTATUS dcerpc_wkssvc_NetrWorkstationStatisticsGet_r(struct dcerpc_binding_hand
 struct tevent_req *dcerpc_wkssvc_NetrWorkstationStatisticsGet_send(TALLOC_CTX *mem_ctx,
 								   struct tevent_context *ev,
 								   struct dcerpc_binding_handle *h,
-								   const char *_server_name /* [in] [unique,charset(UTF16)] */,
+								   const char *_server_name /* [in] [charset(UTF16),unique] */,
 								   const char *_unknown2 /* [in] [charset(UTF16),unique] */,
 								   uint32_t _unknown3 /* [in]  */,
 								   uint32_t _unknown4 /* [in]  */,
@@ -336,7 +336,7 @@ NTSTATUS dcerpc_wkssvc_NetrWorkstationStatisticsGet_recv(struct tevent_req *req,
 							 WERROR *result);
 NTSTATUS dcerpc_wkssvc_NetrWorkstationStatisticsGet(struct dcerpc_binding_handle *h,
 						    TALLOC_CTX *mem_ctx,
-						    const char *_server_name /* [in] [unique,charset(UTF16)] */,
+						    const char *_server_name /* [in] [charset(UTF16),unique] */,
 						    const char *_unknown2 /* [in] [charset(UTF16),unique] */,
 						    uint32_t _unknown3 /* [in]  */,
 						    uint32_t _unknown4 /* [in]  */,
@@ -370,13 +370,13 @@ NTSTATUS dcerpc_wkssvc_NetrLogonDomainNameDel_r(struct dcerpc_binding_handle *h,
 struct tevent_req *dcerpc_wkssvc_NetrLogonDomainNameDel_send(TALLOC_CTX *mem_ctx,
 							     struct tevent_context *ev,
 							     struct dcerpc_binding_handle *h,
-							     const char *_domain_name /* [in] [ref,charset(UTF16)] */);
+							     const char *_domain_name /* [in] [charset(UTF16),ref] */);
 NTSTATUS dcerpc_wkssvc_NetrLogonDomainNameDel_recv(struct tevent_req *req,
 						   TALLOC_CTX *mem_ctx,
 						   WERROR *result);
 NTSTATUS dcerpc_wkssvc_NetrLogonDomainNameDel(struct dcerpc_binding_handle *h,
 					      TALLOC_CTX *mem_ctx,
-					      const char *_domain_name /* [in] [ref,charset(UTF16)] */,
+					      const char *_domain_name /* [in] [charset(UTF16),ref] */,
 					      WERROR *result);
 
 struct tevent_req *dcerpc_wkssvc_NetrJoinDomain_r_send(TALLOC_CTX *mem_ctx,
@@ -389,10 +389,10 @@ struct tevent_req *dcerpc_wkssvc_NetrJoinDomain_send(TALLOC_CTX *mem_ctx,
 						     struct tevent_context *ev,
 						     struct dcerpc_binding_handle *h,
 						     const char *_server_name /* [in] [unique,charset(UTF16)] */,
-						     const char *_domain_name /* [in] [charset(UTF16),ref] */,
-						     const char *_account_ou /* [in] [unique,charset(UTF16)] */,
+						     const char *_domain_name /* [in] [ref,charset(UTF16)] */,
+						     const char *_account_ou /* [in] [charset(UTF16),unique] */,
 						     const char *_Account /* [in] [unique,charset(UTF16)] */,
-						     const char *_password /* [in] [unique,charset(UTF16)] */,
+						     const char *_password /* [in] [charset(UTF16),unique] */,
 						     uint32_t _join_flags /* [in]  */);
 NTSTATUS dcerpc_wkssvc_NetrJoinDomain_recv(struct tevent_req *req,
 					   TALLOC_CTX *mem_ctx,
@@ -400,10 +400,10 @@ NTSTATUS dcerpc_wkssvc_NetrJoinDomain_recv(struct tevent_req *req,
 NTSTATUS dcerpc_wkssvc_NetrJoinDomain(struct dcerpc_binding_handle *h,
 				      TALLOC_CTX *mem_ctx,
 				      const char *_server_name /* [in] [unique,charset(UTF16)] */,
-				      const char *_domain_name /* [in] [charset(UTF16),ref] */,
-				      const char *_account_ou /* [in] [unique,charset(UTF16)] */,
+				      const char *_domain_name /* [in] [ref,charset(UTF16)] */,
+				      const char *_account_ou /* [in] [charset(UTF16),unique] */,
 				      const char *_Account /* [in] [unique,charset(UTF16)] */,
-				      const char *_password /* [in] [unique,charset(UTF16)] */,
+				      const char *_password /* [in] [charset(UTF16),unique] */,
 				      uint32_t _join_flags /* [in]  */,
 				      WERROR *result);
 
@@ -417,7 +417,7 @@ struct tevent_req *dcerpc_wkssvc_NetrUnjoinDomain_send(TALLOC_CTX *mem_ctx,
 						       struct tevent_context *ev,
 						       struct dcerpc_binding_handle *h,
 						       const char *_server_name /* [in] [charset(UTF16),unique] */,
-						       const char *_Account /* [in] [unique,charset(UTF16)] */,
+						       const char *_Account /* [in] [charset(UTF16),unique] */,
 						       const char *_password /* [in] [charset(UTF16),unique] */,
 						       uint32_t _unjoin_flags /* [in]  */);
 NTSTATUS dcerpc_wkssvc_NetrUnjoinDomain_recv(struct tevent_req *req,
@@ -426,7 +426,7 @@ NTSTATUS dcerpc_wkssvc_NetrUnjoinDomain_recv(struct tevent_req *req,
 NTSTATUS dcerpc_wkssvc_NetrUnjoinDomain(struct dcerpc_binding_handle *h,
 					TALLOC_CTX *mem_ctx,
 					const char *_server_name /* [in] [charset(UTF16),unique] */,
-					const char *_Account /* [in] [unique,charset(UTF16)] */,
+					const char *_Account /* [in] [charset(UTF16),unique] */,
 					const char *_password /* [in] [charset(UTF16),unique] */,
 					uint32_t _unjoin_flags /* [in]  */,
 					WERROR *result);
@@ -440,20 +440,20 @@ NTSTATUS dcerpc_wkssvc_NetrRenameMachineInDomain_r(struct dcerpc_binding_handle
 struct tevent_req *dcerpc_wkssvc_NetrRenameMachineInDomain_send(TALLOC_CTX *mem_ctx,
 								struct tevent_context *ev,
 								struct dcerpc_binding_handle *h,
-								const char *_server_name /* [in] [charset(UTF16),unique] */,
-								const char *_NewMachineName /* [in] [charset(UTF16),unique] */,
-								const char *_Account /* [in] [unique,charset(UTF16)] */,
-								const char *_password /* [in] [charset(UTF16),unique] */,
+								const char *_server_name /* [in] [unique,charset(UTF16)] */,
+								const char *_NewMachineName /* [in] [unique,charset(UTF16)] */,
+								const char *_Account /* [in] [charset(UTF16),unique] */,
+								const char *_password /* [in] [unique,charset(UTF16)] */,
 								uint32_t _RenameOptions /* [in]  */);
 NTSTATUS dcerpc_wkssvc_NetrRenameMachineInDomain_recv(struct tevent_req *req,
 						      TALLOC_CTX *mem_ctx,
 						      WERROR *result);
 NTSTATUS dcerpc_wkssvc_NetrRenameMachineInDomain(struct dcerpc_binding_handle *h,
 						 TALLOC_CTX *mem_ctx,
-						 const char *_server_name /* [in] [charset(UTF16),unique] */,
-						 const char *_NewMachineName /* [in] [charset(UTF16),unique] */,
-						 const char *_Account /* [in] [unique,charset(UTF16)] */,
-						 const char *_password /* [in] [charset(UTF16),unique] */,
+						 const char *_server_name /* [in] [unique,charset(UTF16)] */,
+						 const char *_NewMachineName /* [in] [unique,charset(UTF16)] */,
+						 const char *_Account /* [in] [charset(UTF16),unique] */,
+						 const char *_password /* [in] [unique,charset(UTF16)] */,
 						 uint32_t _RenameOptions /* [in]  */,
 						 WERROR *result);
 
@@ -466,9 +466,9 @@ NTSTATUS dcerpc_wkssvc_NetrValidateName_r(struct dcerpc_binding_handle *h, TALLO
 struct tevent_req *dcerpc_wkssvc_NetrValidateName_send(TALLOC_CTX *mem_ctx,
 						       struct tevent_context *ev,
 						       struct dcerpc_binding_handle *h,
-						       const char *_server_name /* [in] [charset(UTF16),unique] */,
+						       const char *_server_name /* [in] [unique,charset(UTF16)] */,
 						       const char *_name /* [in] [ref,charset(UTF16)] */,
-						       const char *_Account /* [in] [charset(UTF16),unique] */,
+						       const char *_Account /* [in] [unique,charset(UTF16)] */,
 						       const char *_Password /* [in] [charset(UTF16),unique] */,
 						       enum wkssvc_NetValidateNameType _name_type /* [in]  */);
 NTSTATUS dcerpc_wkssvc_NetrValidateName_recv(struct tevent_req *req,
@@ -476,9 +476,9 @@ NTSTATUS dcerpc_wkssvc_NetrValidateName_recv(struct tevent_req *req,
 					     WERROR *result);
 NTSTATUS dcerpc_wkssvc_NetrValidateName(struct dcerpc_binding_handle *h,
 					TALLOC_CTX *mem_ctx,
-					const char *_server_name /* [in] [charset(UTF16),unique] */,
+					const char *_server_name /* [in] [unique,charset(UTF16)] */,
 					const char *_name /* [in] [ref,charset(UTF16)] */,
-					const char *_Account /* [in] [charset(UTF16),unique] */,
+					const char *_Account /* [in] [unique,charset(UTF16)] */,
 					const char *_Password /* [in] [charset(UTF16),unique] */,
 					enum wkssvc_NetValidateNameType _name_type /* [in]  */,
 					WERROR *result);
@@ -492,16 +492,16 @@ NTSTATUS dcerpc_wkssvc_NetrGetJoinInformation_r(struct dcerpc_binding_handle *h,
 struct tevent_req *dcerpc_wkssvc_NetrGetJoinInformation_send(TALLOC_CTX *mem_ctx,
 							     struct tevent_context *ev,
 							     struct dcerpc_binding_handle *h,
-							     const char *_server_name /* [in] [charset(UTF16),unique] */,
-							     const char **_name_buffer /* [in,out] [charset(UTF16),ref] */,
+							     const char *_server_name /* [in] [unique,charset(UTF16)] */,
+							     const char **_name_buffer /* [in,out] [ref,charset(UTF16)] */,
 							     enum wkssvc_NetJoinStatus *_name_type /* [out] [ref] */);
 NTSTATUS dcerpc_wkssvc_NetrGetJoinInformation_recv(struct tevent_req *req,
 						   TALLOC_CTX *mem_ctx,
 						   WERROR *result);
 NTSTATUS dcerpc_wkssvc_NetrGetJoinInformation(struct dcerpc_binding_handle *h,
 					      TALLOC_CTX *mem_ctx,
-					      const char *_server_name /* [in] [charset(UTF16),unique] */,
-					      const char **_name_buffer /* [in,out] [charset(UTF16),ref] */,
+					      const char *_server_name /* [in] [unique,charset(UTF16)] */,
+					      const char **_name_buffer /* [in,out] [ref,charset(UTF16)] */,
 					      enum wkssvc_NetJoinStatus *_name_type /* [out] [ref] */,
 					      WERROR *result);
 
@@ -515,7 +515,7 @@ struct tevent_req *dcerpc_wkssvc_NetrGetJoinableOus_send(TALLOC_CTX *mem_ctx,
 							 struct tevent_context *ev,
 							 struct dcerpc_binding_handle *h,
 							 const char *_server_name /* [in] [charset(UTF16),unique] */,
-							 const char *_domain_name /* [in] [ref,charset(UTF16)] */,
+							 const char *_domain_name /* [in] [charset(UTF16),ref] */,
 							 const char *_Account /* [in] [unique,charset(UTF16)] */,
 							 const char *_unknown /* [in] [unique,charset(UTF16)] */,
 							 uint32_t *_num_ous /* [in,out] [ref] */,
@@ -526,7 +526,7 @@ NTSTATUS dcerpc_wkssvc_NetrGetJoinableOus_recv(struct tevent_req *req,
 NTSTATUS dcerpc_wkssvc_NetrGetJoinableOus(struct dcerpc_binding_handle *h,
 					  TALLOC_CTX *mem_ctx,
 					  const char *_server_name /* [in] [charset(UTF16),unique] */,
-					  const char *_domain_name /* [in] [ref,charset(UTF16)] */,
+					  const char *_domain_name /* [in] [charset(UTF16),ref] */,
 					  const char *_Account /* [in] [unique,charset(UTF16)] */,
 					  const char *_unknown /* [in] [unique,charset(UTF16)] */,
 					  uint32_t *_num_ous /* [in,out] [ref] */,
@@ -543,9 +543,9 @@ struct tevent_req *dcerpc_wkssvc_NetrJoinDomain2_send(TALLOC_CTX *mem_ctx,
 						      struct tevent_context *ev,
 						      struct dcerpc_binding_handle *h,
 						      const char *_server_name /* [in] [charset(UTF16),unique] */,
-						      const char *_domain_name /* [in] [ref,charset(UTF16)] */,
+						      const char *_domain_name /* [in] [charset(UTF16),ref] */,
 						      const char *_account_ou /* [in] [charset(UTF16),unique] */,
-						      const char *_admin_account /* [in] [charset(UTF16),unique] */,
+						      const char *_admin_account /* [in] [unique,charset(UTF16)] */,
 						      struct wkssvc_PasswordBuffer *_encrypted_password /* [in] [unique] */,
 						      uint32_t _join_flags /* [in]  */);
 NTSTATUS dcerpc_wkssvc_NetrJoinDomain2_recv(struct tevent_req *req,
@@ -554,9 +554,9 @@ NTSTATUS dcerpc_wkssvc_NetrJoinDomain2_recv(struct tevent_req *req,
 NTSTATUS dcerpc_wkssvc_NetrJoinDomain2(struct dcerpc_binding_handle *h,
 				       TALLOC_CTX *mem_ctx,
 				       const char *_server_name /* [in] [charset(UTF16),unique] */,
-				       const char *_domain_name /* [in] [ref,charset(UTF16)] */,
+				       const char *_domain_name /* [in] [charset(UTF16),ref] */,
 				       const char *_account_ou /* [in] [charset(UTF16),unique] */,
-				       const char *_admin_account /* [in] [charset(UTF16),unique] */,
+				       const char *_admin_account /* [in] [unique,charset(UTF16)] */,
 				       struct wkssvc_PasswordBuffer *_encrypted_password /* [in] [unique] */,
 				       uint32_t _join_flags /* [in]  */,
 				       WERROR *result);
@@ -570,8 +570,8 @@ NTSTATUS dcerpc_wkssvc_NetrUnjoinDomain2_r(struct dcerpc_binding_handle *h, TALL
 struct tevent_req *dcerpc_wkssvc_NetrUnjoinDomain2_send(TALLOC_CTX *mem_ctx,
 							struct tevent_context *ev,
 							struct dcerpc_binding_handle *h,
-							const char *_server_name /* [in] [charset(UTF16),unique] */,
-							const char *_account /* [in] [charset(UTF16),unique] */,
+							const char *_server_name /* [in] [unique,charset(UTF16)] */,
+							const char *_account /* [in] [unique,charset(UTF16)] */,
 							struct wkssvc_PasswordBuffer *_encrypted_password /* [in] [unique] */,
 							uint32_t _unjoin_flags /* [in]  */);
 NTSTATUS dcerpc_wkssvc_NetrUnjoinDomain2_recv(struct tevent_req *req,
@@ -579,8 +579,8 @@ NTSTATUS dcerpc_wkssvc_NetrUnjoinDomain2_recv(struct tevent_req *req,
 					      WERROR *result);
 NTSTATUS dcerpc_wkssvc_NetrUnjoinDomain2(struct dcerpc_binding_handle *h,
 					 TALLOC_CTX *mem_ctx,
-					 const char *_server_name /* [in] [charset(UTF16),unique] */,
-					 const char *_account /* [in] [charset(UTF16),unique] */,
+					 const char *_server_name /* [in] [unique,charset(UTF16)] */,
+					 const char *_account /* [in] [unique,charset(UTF16)] */,
 					 struct wkssvc_PasswordBuffer *_encrypted_password /* [in] [unique] */,
 					 uint32_t _unjoin_flags /* [in]  */,
 					 WERROR *result);
@@ -594,7 +594,7 @@ NTSTATUS dcerpc_wkssvc_NetrRenameMachineInDomain2_r(struct dcerpc_binding_handle
 struct tevent_req *dcerpc_wkssvc_NetrRenameMachineInDomain2_send(TALLOC_CTX *mem_ctx,
 								 struct tevent_context *ev,
 								 struct dcerpc_binding_handle *h,
-								 const char *_server_name /* [in] [charset(UTF16),unique] */,
+								 const char *_server_name /* [in] [unique,charset(UTF16)] */,
 								 const char *_NewMachineName /* [in] [unique,charset(UTF16)] */,
 								 const char *_Account /* [in] [charset(UTF16),unique] */,
 								 struct wkssvc_PasswordBuffer *_EncryptedPassword /* [in] [unique] */,
@@ -604,7 +604,7 @@ NTSTATUS dcerpc_wkssvc_NetrRenameMachineInDomain2_recv(struct tevent_req *req,
 						       WERROR *result);
 NTSTATUS dcerpc_wkssvc_NetrRenameMachineInDomain2(struct dcerpc_binding_handle *h,
 						  TALLOC_CTX *mem_ctx,
-						  const char *_server_name /* [in] [charset(UTF16),unique] */,
+						  const char *_server_name /* [in] [unique,charset(UTF16)] */,
 						  const char *_NewMachineName /* [in] [unique,charset(UTF16)] */,
 						  const char *_Account /* [in] [charset(UTF16),unique] */,
 						  struct wkssvc_PasswordBuffer *_EncryptedPassword /* [in] [unique] */,
@@ -620,9 +620,9 @@ NTSTATUS dcerpc_wkssvc_NetrValidateName2_r(struct dcerpc_binding_handle *h, TALL
 struct tevent_req *dcerpc_wkssvc_NetrValidateName2_send(TALLOC_CTX *mem_ctx,
 							struct tevent_context *ev,
 							struct dcerpc_binding_handle *h,
-							const char *_server_name /* [in] [unique,charset(UTF16)] */,
-							const char *_name /* [in] [charset(UTF16),ref] */,
-							const char *_Account /* [in] [unique,charset(UTF16)] */,
+							const char *_server_name /* [in] [charset(UTF16),unique] */,
+							const char *_name /* [in] [ref,charset(UTF16)] */,
+							const char *_Account /* [in] [charset(UTF16),unique] */,
 							struct wkssvc_PasswordBuffer *_EncryptedPassword /* [in] [unique] */,
 							enum wkssvc_NetValidateNameType _name_type /* [in]  */);
 NTSTATUS dcerpc_wkssvc_NetrValidateName2_recv(struct tevent_req *req,
@@ -630,9 +630,9 @@ NTSTATUS dcerpc_wkssvc_NetrValidateName2_recv(struct tevent_req *req,
 					      WERROR *result);
 NTSTATUS dcerpc_wkssvc_NetrValidateName2(struct dcerpc_binding_handle *h,
 					 TALLOC_CTX *mem_ctx,
-					 const char *_server_name /* [in] [unique,charset(UTF16)] */,
-					 const char *_name /* [in] [charset(UTF16),ref] */,
-					 const char *_Account /* [in] [unique,charset(UTF16)] */,
+					 const char *_server_name /* [in] [charset(UTF16),unique] */,
+					 const char *_name /* [in] [ref,charset(UTF16)] */,
+					 const char *_Account /* [in] [charset(UTF16),unique] */,
 					 struct wkssvc_PasswordBuffer *_EncryptedPassword /* [in] [unique] */,
 					 enum wkssvc_NetValidateNameType _name_type /* [in]  */,
 					 WERROR *result);
@@ -646,23 +646,23 @@ NTSTATUS dcerpc_wkssvc_NetrGetJoinableOus2_r(struct dcerpc_binding_handle *h, TA
 struct tevent_req *dcerpc_wkssvc_NetrGetJoinableOus2_send(TALLOC_CTX *mem_ctx,
 							  struct tevent_context *ev,
 							  struct dcerpc_binding_handle *h,
-							  const char *_server_name /* [in] [unique,charset(UTF16)] */,
-							  const char *_domain_name /* [in] [ref,charset(UTF16)] */,
-							  const char *_Account /* [in] [unique,charset(UTF16)] */,
+							  const char *_server_name /* [in] [charset(UTF16),unique] */,
+							  const char *_domain_name /* [in] [charset(UTF16),ref] */,
+							  const char *_Account /* [in] [charset(UTF16),unique] */,
 							  struct wkssvc_PasswordBuffer *_EncryptedPassword /* [in] [unique] */,
 							  uint32_t *_num_ous /* [in,out] [ref] */,
-							  const char ***_ous /* [out] [ref,size_is(,*num_ous),charset(UTF16)] */);
+							  const char ***_ous /* [out] [charset(UTF16),size_is(,*num_ous),ref] */);
 NTSTATUS dcerpc_wkssvc_NetrGetJoinableOus2_recv(struct tevent_req *req,
 						TALLOC_CTX *mem_ctx,
 						WERROR *result);
 NTSTATUS dcerpc_wkssvc_NetrGetJoinableOus2(struct dcerpc_binding_handle *h,
 					   TALLOC_CTX *mem_ctx,
-					   const char *_server_name /* [in] [unique,charset(UTF16)] */,
-					   const char *_domain_name /* [in] [ref,charset(UTF16)] */,
-					   const char *_Account /* [in] [unique,charset(UTF16)] */,
+					   const char *_server_name /* [in] [charset(UTF16),unique] */,
+					   const char *_domain_name /* [in] [charset(UTF16),ref] */,
+					   const char *_Account /* [in] [charset(UTF16),unique] */,
 					   struct wkssvc_PasswordBuffer *_EncryptedPassword /* [in] [unique] */,
 					   uint32_t *_num_ous /* [in,out] [ref] */,
-					   const char ***_ous /* [out] [ref,size_is(,*num_ous),charset(UTF16)] */,
+					   const char ***_ous /* [out] [charset(UTF16),size_is(,*num_ous),ref] */,
 					   WERROR *result);
 
 struct tevent_req *dcerpc_wkssvc_NetrAddAlternateComputerName_r_send(TALLOC_CTX *mem_ctx,
@@ -676,7 +676,7 @@ struct tevent_req *dcerpc_wkssvc_NetrAddAlternateComputerName_send(TALLOC_CTX *m
 								   struct dcerpc_binding_handle *h,
 								   const char *_server_name /* [in] [charset(UTF16),unique] */,
 								   const char *_NewAlternateMachineName /* [in] [unique,charset(UTF16)] */,
-								   const char *_Account /* [in] [charset(UTF16),unique] */,
+								   const char *_Account /* [in] [unique,charset(UTF16)] */,
 								   struct wkssvc_PasswordBuffer *_EncryptedPassword /* [in] [unique] */,
 								   uint32_t _Reserved /* [in]  */);
 NTSTATUS dcerpc_wkssvc_NetrAddAlternateComputerName_recv(struct tevent_req *req,
@@ -686,7 +686,7 @@ NTSTATUS dcerpc_wkssvc_NetrAddAlternateComputerName(struct dcerpc_binding_handle
 						    TALLOC_CTX *mem_ctx,
 						    const char *_server_name /* [in] [charset(UTF16),unique] */,
 						    const char *_NewAlternateMachineName /* [in] [unique,charset(UTF16)] */,
-						    const char *_Account /* [in] [charset(UTF16),unique] */,
+						    const char *_Account /* [in] [unique,charset(UTF16)] */,
 						    struct wkssvc_PasswordBuffer *_EncryptedPassword /* [in] [unique] */,
 						    uint32_t _Reserved /* [in]  */,
 						    WERROR *result);
@@ -700,9 +700,9 @@ NTSTATUS dcerpc_wkssvc_NetrRemoveAlternateComputerName_r(struct dcerpc_binding_h
 struct tevent_req *dcerpc_wkssvc_NetrRemoveAlternateComputerName_send(TALLOC_CTX *mem_ctx,
 								      struct tevent_context *ev,
 								      struct dcerpc_binding_handle *h,
-								      const char *_server_name /* [in] [unique,charset(UTF16)] */,
-								      const char *_AlternateMachineNameToRemove /* [in] [unique,charset(UTF16)] */,
-								      const char *_Account /* [in] [charset(UTF16),unique] */,
+								      const char *_server_name /* [in] [charset(UTF16),unique] */,
+								      const char *_AlternateMachineNameToRemove /* [in] [charset(UTF16),unique] */,
+								      const char *_Account /* [in] [unique,charset(UTF16)] */,
 								      struct wkssvc_PasswordBuffer *_EncryptedPassword /* [in] [unique] */,
 								      uint32_t _Reserved /* [in]  */);
 NTSTATUS dcerpc_wkssvc_NetrRemoveAlternateComputerName_recv(struct tevent_req *req,
@@ -710,9 +710,9 @@ NTSTATUS dcerpc_wkssvc_NetrRemoveAlternateComputerName_recv(struct tevent_req *r
 							    WERROR *result);
 NTSTATUS dcerpc_wkssvc_NetrRemoveAlternateComputerName(struct dcerpc_binding_handle *h,
 						       TALLOC_CTX *mem_ctx,
-						       const char *_server_name /* [in] [unique,charset(UTF16)] */,
-						       const char *_AlternateMachineNameToRemove /* [in] [unique,charset(UTF16)] */,
-						       const char *_Account /* [in] [charset(UTF16),unique] */,
+						       const char *_server_name /* [in] [charset(UTF16),unique] */,
+						       const char *_AlternateMachineNameToRemove /* [in] [charset(UTF16),unique] */,
+						       const char *_Account /* [in] [unique,charset(UTF16)] */,
 						       struct wkssvc_PasswordBuffer *_EncryptedPassword /* [in] [unique] */,
 						       uint32_t _Reserved /* [in]  */,
 						       WERROR *result);
@@ -726,7 +726,7 @@ NTSTATUS dcerpc_wkssvc_NetrSetPrimaryComputername_r(struct dcerpc_binding_handle
 struct tevent_req *dcerpc_wkssvc_NetrSetPrimaryComputername_send(TALLOC_CTX *mem_ctx,
 								 struct tevent_context *ev,
 								 struct dcerpc_binding_handle *h,
-								 const char *_server_name /* [in] [unique,charset(UTF16)] */,
+								 const char *_server_name /* [in] [charset(UTF16),unique] */,
 								 const char *_primary_name /* [in] [unique,charset(UTF16)] */,
 								 const char *_Account /* [in] [unique,charset(UTF16)] */,
 								 struct wkssvc_PasswordBuffer *_EncryptedPassword /* [in] [unique] */,
@@ -736,7 +736,7 @@ NTSTATUS dcerpc_wkssvc_NetrSetPrimaryComputername_recv(struct tevent_req *req,
 						       WERROR *result);
 NTSTATUS dcerpc_wkssvc_NetrSetPrimaryComputername(struct dcerpc_binding_handle *h,
 						  TALLOC_CTX *mem_ctx,
-						  const char *_server_name /* [in] [unique,charset(UTF16)] */,
+						  const char *_server_name /* [in] [charset(UTF16),unique] */,
 						  const char *_primary_name /* [in] [unique,charset(UTF16)] */,
 						  const char *_Account /* [in] [unique,charset(UTF16)] */,
 						  struct wkssvc_PasswordBuffer *_EncryptedPassword /* [in] [unique] */,
