@@ -99,13 +99,22 @@ static void exit_server_common(enum server_exit_reason how,
 
 	change_to_root_user();
 
-	if (sconn && sconn->smb1.negprot.auth_context) {
-		TALLOC_FREE(sconn->smb1.negprot.auth_context);
-	}
-
 	if (sconn) {
 		NTSTATUS status;
 
+		if (NT_STATUS_IS_OK(sconn->status)) {
+			switch (how) {
+			case SERVER_EXIT_ABNORMAL:
+				sconn->status = NT_STATUS_INTERNAL_ERROR;
+				break;
+			case SERVER_EXIT_NORMAL:
+				sconn->status = NT_STATUS_LOCAL_DISCONNECT;
+				break;
+			}
+		}
+
+		TALLOC_FREE(sconn->smb1.negprot.auth_context);
+
 		if (lp_log_writeable_files_on_exit()) {
 			bool found = false;
 			files_forall(sconn, log_writeable_file_fn, &found);
